@@ -4,7 +4,7 @@ from pathlib import Path
 
 from briefcase.cmdline import parse_cmdline
 from briefcase.console import Console, Log
-from briefcase.exceptions import BriefcaseError, HelpText
+from briefcase.exceptions import BriefcaseError, BriefcaseTestSuiteFailure, HelpText
 
 
 def main():
@@ -16,13 +16,16 @@ def main():
         Command, extra_cmdline = parse_cmdline(sys.argv[1:])
         command = Command(logger=logger, console=console)
         options = command.parse_options(extra=extra_cmdline)
-        command.check_obsolete_data_dir()
         command.parse_config(Path.cwd() / "pyproject.toml")
         command(**options)
     except HelpText as e:
         logger.info()
         logger.info(str(e))
         result = e.error_code
+    except BriefcaseTestSuiteFailure as e:
+        # Test suite status is logged when the test is executed.
+        # Set the return code, but don't log anything else.
+        result = e.error_code
     except BriefcaseError as e:
         logger.error()
         logger.error(str(e))
