@@ -3,14 +3,19 @@ import importlib
 import inspect
 import os
 import platform
+import shutil
 import subprocess
+import textwrap
 from abc import ABC, abstractmethod
+from argparse import RawDescriptionHelpFormatter
 from pathlib import Path
 
 from cookiecutter import exceptions as cookiecutter_exceptions
 from cookiecutter.repository import is_repo_url
 from platformdirs import PlatformDirs
 
+from briefcase.platforms import get_output_formats, get_platforms
+
 try:
     import tomllib
 except ModuleNotFoundError:
@@ -22,10 +27,11 @@ from briefcase.console import Console, Log
 from briefcase.exceptions import (
     BriefcaseCommandError,
     BriefcaseConfigError,
-    InfoHelpText,
     NetworkFailure,
 )
 from briefcase.integrations.base import ToolCache
+from briefcase.integrations.download import Download
+from briefcase.integrations.subprocess import Subprocess
 
 
 class InvalidTemplateRepository(BriefcaseCommandError):
@@ -50,7 +56,7 @@ class UnsupportedPlatform(BriefcaseCommandError):
         super().__init__(
             f"""\
 App cannot be deployed on {platform}. This is probably because one or more
-dependencies (e.g., the GUI library) doesn't support {platform}.
+requirements (e.g., the GUI library) doesn't support {platform}.
 """
         )
 
@@ -146,6 +152,10 @@ class BaseCommand(ABC):
             base_path=self.data_path / "tools",
         )
 
+        # Immediately add tools that must be always available
+        Subprocess.verify(tools=self.tools)
+        Download.verify(tools=self.tools)
+
         self.global_config = None
         self._path_index = {}
 
@@ -157,86 +167,6 @@ class BaseCommand(ABC):
     def input(self):
         return self.tools.input
 
-    def check_obsolete_data_dir(self):
-        """Inform user if obsolete data directory exists.
-
-        TODO: Remove this check after 1 JAN 2023 since most users will have transitioned by then
-
-        Previous versions used the ~/.briefcase directory to store
-        downloads, tools, etc. This check lets users know the old
-        directory still exists and their options to migrate or clean up.
-        """
-        dot_briefcase_path = self.tools.home_path / ".briefcase"
-
-        # If there's no .briefcase path, no need to check for migration.
-        if not dot_briefcase_path.exists():
-            return
-
-        # If the data path is user-provided, don't check for migration.
-        if "BRIEFCASE_HOME" in os.environ:
-            return
-
-        if self.data_path.exists():
-            self.logger.warning(
-                f"""\
-Briefcase is no longer using the data directory:
-
-    {dot_briefcase_path}
-
-This directory can be safely deleted.
-"""
-            )
-        else:
-            self.logger.warning(
-                f"""\
-*************************************************************************
-** NOTICE: Briefcase is changing its data directory                   **
-*************************************************************************
-
-    Briefcase is moving its data directory from:
-
-        {dot_briefcase_path}
-
-    to:
-
-        {self.data_path}
-
-    If you continue, Briefcase will re-download the tools and data it
-    uses to build and package applications.
-
-    To avoid potentially large downloads and long installations, you
-    can manually move the old data directory to the new location.
-
-    If you continue and allow Briefcase to re-download its tools, the
-    old data directory can be safely deleted.
-
-*************************************************************************
-"""
-            )
-            self.input.prompt()
-            if not self.input.boolean_input(
-                "Do you want to re-download the Briefcase support tools",
-                # Default to continuing for non-interactive runs
-                default=not self.input.enabled,
-            ):
-                raise InfoHelpText(
-                    f"""\
-Move the Briefcase data directory from:
-
-    {dot_briefcase_path}
-
-to:
-
-    {self.data_path}
-
-or delete the old data directory, and re-run Briefcase.
-
-"""
-                )
-
-            # Create data directory to prevent full notice showing again.
-            self.data_path.mkdir(parents=True, exist_ok=True)
-
     def validate_data_path(self, data_path):
         """Validate provided data path or determine OS-specific path.
 
@@ -267,7 +197,9 @@ or delete the old data directory, and re-run Briefcase.
                     appauthor="BeeWare",
                 ).user_cache_path
 
-        if " " in os.fsdecode(data_path):
+        data_path = os.fsdecode(data_path)
+
+        if " " in data_path:
             raise BriefcaseCommandError(
                 f"""
 The location Briefcase will use to store tools and support files:
@@ -283,6 +215,37 @@ a custom location for Briefcase's tools.
 """
             )
 
+        if not os.path.exists(data_path):
+            try:
+                # The Windows Store version of Python can redirect filesystem
+                # interactions within %LOCALAPPDATA% to a sandboxed location.
+                # To bypass this, the Briefcase cache directory creation is
+                # performed via ``cmd.exe`` in a different process. Once this
+                # directory exists in the "real" %LOCALAPPDATA%, Windows will
+                # allow normal interactions without attempting to sandbox them.
+                if platform.system() == "Windows":
+                    subprocess.run(
+                        ["mkdir", data_path],
+                        shell=True,
+                        check=True,
+                        stdout=subprocess.DEVNULL,
+                        stderr=subprocess.DEVNULL,
+                    )
+                else:
+                    os.makedirs(data_path, exist_ok=True)
+            except (subprocess.CalledProcessError, OSError):
+                raise BriefcaseCommandError(
+                    f"""
+Failed to create the Briefcase directory to store tools and support files:
+
+    {data_path}
+
+You can set the environment variable BRIEFCASE_HOME to specify
+a custom location for Briefcase's tools.
+
+"""
+                )
+
         return Path(data_path)
 
     def _command_factory(self, command_name: str):
@@ -446,10 +409,10 @@ a custom location for Briefcase's tools.
         return self.bundle_path(app) / path_index["app_requirements_path"]
 
     def app_packages_path(self, app: BaseConfig):
-        """Obtain the path into which dependencies should be installed.
+        """Obtain the path into which requirements should be installed.
 
         :param app: The config object for the app
-        :return: The full path where application dependencies should be installed.
+        :return: The full path where application requirements should be installed.
         """
         # If the index file hasn't been loaded for this app, load it.
         try:
@@ -520,13 +483,44 @@ a custom location for Briefcase's tools.
         pass
 
     def parse_options(self, extra):
+        """Parse the command line arguments for the Command.
+
+        After the initial ArgumentParser runs to choose the Command for the
+        selected platform and format, a new ArgumentParser is created here to
+        parse the remaining command line arguments specific to the Command.
+        Additionally, the default options for disabling input, log verbosity,
+        and log saving are parsed out and saved to the Command.
+
+        :param extra: the remaining command line arguments after the initial
+            ArgumentParser runs over the command line.
+        :return: dictionary of parsed arguments for Command
+        """
+        default_format = getattr(
+            get_platforms().get(self.platform), "DEFAULT_OUTPUT_FORMAT", None
+        )
+        # only show supported formats for Commands that support formats
+        if default_format is not None and self.command not in {"new", "dev", "upgrade"}:
+            formats = list(get_output_formats(self.platform).keys())
+            formats[formats.index(default_format)] = f"{default_format} (default)"
+            supported_formats_helptext = (
+                "\nSupported formats:\n"
+                f"  {', '.join(sorted(formats, key=str.lower))}"
+            )
+        else:
+            supported_formats_helptext = ""
+
+        width = max(min(shutil.get_terminal_size().columns, 80) - 2, 20)
         parser = argparse.ArgumentParser(
             prog=self.cmd_line.format(
                 command=self.command,
                 platform=self.platform,
                 output_format=self.output_format,
             ),
-            description=self.description,
+            description=(
+                f"{textwrap.fill(self.description, width=width)}\n"
+                f"{supported_formats_helptext}"
+            ),
+            formatter_class=lambda prog: RawDescriptionHelpFormatter(prog, width=width),
         )
 
         self.add_default_options(parser)
@@ -572,14 +566,70 @@ a custom location for Briefcase's tools.
             help=(
                 "Don't ask for user input. If any action would be destructive, "
                 "an error will be raised; otherwise, default answers will be "
-                "assumed."
+                "assumed"
             ),
         )
         parser.add_argument(
             "--log",
             action="store_true",
             dest="save_log",
-            help="Save a detailed log to file. By default, this log file is only created for critical errors.",
+            help="Save a detailed log to file. By default, this log file is only created for critical errors",
+        )
+
+    def _add_update_options(
+        self,
+        parser,
+        context_label="",
+        update=True,
+    ):
+        """Internal utility method for adding common update options.
+
+        :param parser: The parser to which options should be added.
+        :param context_label: Label text that will be added to the end of the
+            help text to describe when the update will be applied (e.g., "before
+            building")
+        :param update: Should the --update and --no-update options be exposed?
+        """
+        if update:
+            parser.add_argument(
+                "-u",
+                "--update",
+                action="store_true",
+                help=f"Update the app{context_label}",
+            )
+
+        parser.add_argument(
+            "-r",
+            "--update-requirements",
+            action="store_true",
+            help=f"Update requirements for the app{context_label}",
+        )
+
+        parser.add_argument(
+            "--update-resources",
+            action="store_true",
+            help=f"Update app resources (icons, splash screens, etc){context_label}",
+        )
+
+        if update:
+            parser.add_argument(
+                "--no-update",
+                action="store_true",
+                help=f"Prevent any automated update{context_label}",
+            )
+
+    def _add_test_options(self, parser, context_label):
+        """Internal utility method for adding common test-related options.
+
+        :param parser: The parser to which options should be added.
+        :param context_label: Label text for commands; the capitalized action being
+            performed (e.g., "Build", "Run",...)
+        """
+        parser.add_argument(
+            "--test",
+            dest="test_mode",
+            action="store_true",
+            help=f"{context_label} the app in test mode",
         )
 
     def add_options(self, parser):
