@@ -6,7 +6,7 @@ import subprocess
 import sys
 from datetime import date
 from pathlib import Path
-from typing import Optional
+from typing import List, Optional
 
 from packaging.version import Version
 
@@ -47,12 +47,12 @@ is not yet supported on {self.platform}. You will need to:
         )
 
 
-class DependencyInstallError(BriefcaseCommandError):
+class RequirementsInstallError(BriefcaseCommandError):
     def __init__(self):
         super().__init__(
             """\
-Unable to install dependencies. This may be because one of your
-dependencies is invalid, or because pip was unable to connect
+Unable to install requirements. This may be because one of your
+requirements is invalid, or because pip was unable to connect
 to the PyPI server.
 """
         )
@@ -118,6 +118,7 @@ def write_dist_info(app: BaseConfig, dist_info_path: Path):
 
 class CreateCommand(BaseCommand):
     command = "create"
+    description = "Create a new app for a target platform."
 
     def __init__(self, *args, **options):
         super().__init__(*args, **options)
@@ -264,6 +265,7 @@ class CreateCommand(BaseCommand):
                 # The full Python version string, including minor and dev/a/b/c suffixes (e.g., 3.11.0rc2)
                 "python_version": platform.python_version(),
                 # Transformations of explicit properties into useful forms
+                "class_name": app.class_name,
                 "module_name": app.module_name,
                 "package_name": app.package_name,
                 # Properties that are a function of the execution
@@ -291,9 +293,9 @@ class CreateCommand(BaseCommand):
             )
         except TemplateUnsupportedVersion:
             # If we're on a development branch, and the template branch was *not*
-            # provided explicity, we can use a fallback development template.
+            # provided explicitly, we can use a fallback development template.
             # Otherwise, re-raise the exception about the unsupported template version.
-            if version.dev and app.template_branch is None:
+            if version.dev is not None and app.template_branch is None:
                 # Development branches can use the main template.
                 self.logger.info(
                     f"Template branch {template_branch} not found; falling back to development template"
@@ -412,34 +414,44 @@ class CreateCommand(BaseCommand):
                     host_arch=self.tools.host_arch,
                 ) from e
 
-    def _write_requirements_file(self, app: BaseConfig, requirements_path):
-        """Configure application dependencies by writing a requirements.txt
+    def _write_requirements_file(
+        self,
+        app: BaseConfig,
+        requires: List[str],
+        requirements_path: Path,
+    ):
+        """Configure application requirements by writing a requirements.txt
         file.
 
         :param app: The app configuration
+        :param requires: The full list of requirements
         :param requirements_path: The full path to a requirements.txt file that
             will be written.
         """
-        # Windows allows both / and \ as a path separator in requirements.
-        separators = [os.sep]
-        if os.altsep:
-            separators.append(os.altsep)
 
         with self.input.wait_bar("Writing requirements file..."):
             with requirements_path.open("w", encoding="utf-8") as f:
-                if app.requires:
-                    for requirement in app.requires:
+                if requires:
+                    for requirement in requires:
                         # If the requirement is a local path, convert it to
                         # absolute, because Flatpak moves the requirements file
                         # to a different place before using it.
-                        if any(sep in requirement for sep in separators) and (
-                            not _has_url(requirement)
-                        ):
+                        if _is_local_requirement(requirement):
                             # We use os.path.abspath() rather than Path.resolve()
                             # because we *don't* want Path's symlink resolving behavior.
                             requirement = os.path.abspath(self.base_path / requirement)
                         f.write(f"{requirement}\n")
 
+    def _pip_requires(self, app: BaseConfig, requires: List[str]):
+        """Convert the list of requirements to be passed to pip into its final
+        form.
+
+        :param app: The app configuration
+        :param requires: The user-specified list of app requirements
+        :returns: The final list of requirement arguments to pass to pip
+        """
+        return requires
+
     def _extra_pip_args(self, app: BaseConfig):
         """Any additional arguments that must be passed to pip when installing
         packages.
@@ -449,33 +461,47 @@ class CreateCommand(BaseCommand):
         """
         return []
 
-    def _install_app_dependencies(self, app: BaseConfig, app_packages_path):
-        """Install dependencies for the app with pip.
+    def _pip_kwargs(self, app: BaseConfig):
+        """Generate the kwargs to pass when invoking pip.
 
         :param app: The app configuration
+        :returns: The kwargs to pass to the pip call
+        """
+        # If there is a support package provided, add the cross-platform
+        # folder of the support package to the PYTHONPATH. This allows
+        # a support package to specify a sitecustomize.py that will make
+        # pip behave as if it was being run on the target platform.
+        pip_kwargs = {}
+        try:
+            pip_kwargs["env"] = {
+                "PYTHONPATH": str(self.support_path(app) / "platform-site"),
+            }
+        except KeyError:
+            pass
+
+        return pip_kwargs
+
+    def _install_app_requirements(
+        self,
+        app: BaseConfig,
+        requires: List[str],
+        app_packages_path: Path,
+    ):
+        """Install requirements for the app with pip.
+
+        :param app: The app configuration
+        :param requires: The list of requirements to install
         :param app_packages_path: The full path of the app_packages folder into which
-            dependencies should be installed.
+            requirements should be installed.
         """
         # Clear existing dependency directory
         if app_packages_path.is_dir():
             self.tools.shutil.rmtree(app_packages_path)
             self.tools.os.mkdir(app_packages_path)
 
-        # Install dependencies
-        if app.requires:
-            with self.input.wait_bar("Installing app dependencies..."):
-                # If there is a support package provided, add the cross-platform
-                # folder of the support package to the PYTHONPATH. This allows
-                # a support package to specify a sitecustomize.py that will make
-                # pip behave as if it was being run on the target platform.
-                pip_kwargs = {}
-                try:
-                    pip_kwargs["env"] = {
-                        "PYTHONPATH": str(self.support_path(app) / "platform-site"),
-                    }
-                except KeyError:
-                    pass
-
+        # Install requirements
+        if requires:
+            with self.input.wait_bar("Installing app requirements..."):
                 try:
                     self.tools[app].app_context.run(
                         [
@@ -489,46 +515,54 @@ class CreateCommand(BaseCommand):
                             f"--target={app_packages_path}",
                         ]
                         + self._extra_pip_args(app)
-                        + app.requires,
+                        + self._pip_requires(app, requires),
                         check=True,
-                        **pip_kwargs,
+                        **self._pip_kwargs(app),
                     )
                 except subprocess.CalledProcessError as e:
-                    raise DependencyInstallError() from e
+                    raise RequirementsInstallError() from e
         else:
-            self.logger.info("No application dependencies.")
+            self.logger.info("No application requirements.")
 
-    def install_app_dependencies(self, app: BaseConfig):
-        """Handle dependencies for the app.
+    def install_app_requirements(self, app: BaseConfig, test_mode: bool):
+        """Handle requirements for the app.
 
         This will result in either (in preferential order):
          * a requirements.txt file being written at a location specified by
            ``app_requirements_path`` in the template path index
-         * dependencies being installed with pip into the location specified
+         * requirements being installed with pip into the location specified
            by the ``app_packages_path`` in the template path index.
 
+        If ``test_mode`` is True, the test requirements will also be installed.
+
         If the path index doesn't specify either of the path index entries,
         an error is raised.
 
         :param app: The config object for the app
+        :param test_mode: Should the test requirements be installed?
         """
+        requires = app.requires.copy() if app.requires else []
+        if test_mode and app.test_requires:
+            requires.extend(app.test_requires)
+
         try:
-            path = self.app_requirements_path(app)
-            self._write_requirements_file(app, path)
+            requirements_path = self.app_requirements_path(app)
+            self._write_requirements_file(app, requires, requirements_path)
         except KeyError:
             try:
-                path = self.app_packages_path(app)
-                self._install_app_dependencies(app, path)
+                app_packages_path = self.app_packages_path(app)
+                self._install_app_requirements(app, requires, app_packages_path)
             except KeyError as e:
                 raise BriefcaseCommandError(
                     "Application path index file does not define "
                     "`app_requirements_path` or `app_packages_path`"
                 ) from e
 
-    def install_app_code(self, app: BaseConfig):
+    def install_app_code(self, app: BaseConfig, test_mode: bool):
         """Install the application code into the bundle.
 
         :param app: The config object for the app
+        :param test_mode: Should the application test code also be installed?
         """
         # Remove existing app folder if it exists
         app_path = self.app_path(app)
@@ -536,9 +570,13 @@ class CreateCommand(BaseCommand):
             self.tools.shutil.rmtree(app_path)
         self.tools.os.mkdir(app_path)
 
+        sources = app.sources.copy() if app.sources else []
+        if test_mode and app.test_sources:
+            sources.extend(app.test_sources)
+
         # Install app code.
-        if app.sources:
-            for src in app.sources:
+        if sources:
+            for src in sources:
                 with self.input.wait_bar(f"Installing {src}..."):
                     original = self.base_path / src
                     target = app_path / original.name
@@ -582,11 +620,13 @@ class CreateCommand(BaseCommand):
                     full_role = role
                 else:
                     try:
-                        source_filename = f"{source[variant]}{target.suffix}"
                         full_role = f"{variant} {role}"
-                    except (TypeError, KeyError):
+                        source_filename = f"{source[variant]}{target.suffix}"
+                    except TypeError:
+                        source_filename = f"{source}-{variant}{target.suffix}"
+                    except KeyError:
                         self.logger.info(
-                            f"Unable to find {variant} variant for {role}; using default"
+                            f"Unknown variant {variant!r} for {role}; using default"
                         )
                         return
             else:
@@ -606,11 +646,13 @@ class CreateCommand(BaseCommand):
                         full_role = f"{size}px {role}"
                 else:
                     try:
-                        source_filename = f"{source[variant]}-{size}{target.suffix}"
                         full_role = f"{size}px {variant} {role}"
-                    except (TypeError, KeyError):
+                        source_filename = f"{source[variant]}-{size}{target.suffix}"
+                    except TypeError:
+                        source_filename = f"{source}-{variant}-{size}{target.suffix}"
+                    except KeyError:
                         self.logger.info(
-                            f"Unable to find {size}px {variant} variant for {role}; using default"
+                            f"Unknown variant {variant!r} for {size}px {role}; using default"
                         )
                         return
 
@@ -721,10 +763,11 @@ class CreateCommand(BaseCommand):
         else:
             self.logger.info("No app content clean up required.")
 
-    def create_app(self, app: BaseConfig, **options):
+    def create_app(self, app: BaseConfig, test_mode: bool = False, **options):
         """Create an application bundle.
 
         :param app: The config object for the app
+        :param test_mode: Should the app be updated in test mode? (default: False)
         """
         if not app.supported:
             raise UnsupportedPlatform(self.platform)
@@ -753,11 +796,11 @@ class CreateCommand(BaseCommand):
         # are in place since the app tools may be dependent on them.
         self.verify_app_tools(app)
 
-        self.logger.info("Installing dependencies...", prefix=app.app_name)
-        self.install_app_dependencies(app=app)
-
         self.logger.info("Installing application code...", prefix=app.app_name)
-        self.install_app_code(app=app)
+        self.install_app_code(app=app, test_mode=test_mode)
+
+        self.logger.info("Installing requirements...", prefix=app.app_name)
+        self.install_app_requirements(app=app, test_mode=test_mode)
 
         self.logger.info("Installing application resources...", prefix=app.app_name)
         self.install_app_resources(app=app)
@@ -798,9 +841,15 @@ class CreateCommand(BaseCommand):
         return state
 
 
-# Detects any of the URL schemes supported by pip
-# (https://pip.pypa.io/en/stable/topics/vcs-support/).
 def _has_url(requirement):
+    """Determine if the requirement is defined as a URL.
+
+    Detects any of the URL schemes supported by pip
+    (https://pip.pypa.io/en/stable/topics/vcs-support/).
+
+    :param requirement: The requirement to check
+    :returns: True if the requirement is a URL supported by pip.
+    """
     return any(
         f"{scheme}:" in requirement
         for scheme in (
@@ -811,3 +860,17 @@ def _has_url(requirement):
             + ["bzr+http", "bzr+https", "bzr+ssh", "bzr+sftp", "bzr+ftp", "bzr+lp"]
         )
     )
+
+
+def _is_local_requirement(requirement):
+    """Determine if the requirement is a local file path.
+
+    :param requirement: The requirement to check
+    :returns: True if the requirement is a local file path
+    """
+    # Windows allows both / and \ as a path separator in requirements.
+    separators = [os.sep]
+    if os.altsep:
+        separators.append(os.altsep)
+
+    return any(sep in requirement for sep in separators) and (not _has_url(requirement))
