@@ -4,18 +4,19 @@ import sys
 from pathlib import Path
 from typing import Optional
 
+from briefcase.commands.run import RunAppMixin
 from briefcase.config import BaseConfig
 from briefcase.exceptions import BriefcaseCommandError
 
 from .base import BaseCommand
-from .create import DependencyInstallError, write_dist_info
+from .create import RequirementsInstallError, write_dist_info
 
 
-class DevCommand(BaseCommand):
+class DevCommand(RunAppMixin, BaseCommand):
     cmd_line = "briefcase dev"
     command = "dev"
     output_format = None
-    description = "Run a briefcase project in the dev environment"
+    description = "Run a Briefcase project in the dev environment."
 
     @property
     def platform(self):
@@ -41,26 +42,38 @@ class DevCommand(BaseCommand):
     def add_options(self, parser):
         parser.add_argument("-a", "--app", dest="appname", help="The app to run")
         parser.add_argument(
-            "-d",
-            "--update-dependencies",
+            "-r",
+            "--update-requirements",
             action="store_true",
-            help="Update dependencies for app",
+            help="Update requirements for the app",
         )
         parser.add_argument(
             "--no-run",
             dest="run_app",
             action="store_false",
             default=True,
-            help="Do not run the app, just install dependencies.",
+            help="Do not run the app, just install requirements.",
+        )
+        parser.add_argument(
+            "--test",
+            dest="test_mode",
+            action="store_true",
+            help="Run the app in test mode",
         )
 
-    def install_dev_dependencies(self, app: BaseConfig, **options):
-        """Install the dependencies for the app devly.
+    def install_dev_requirements(self, app: BaseConfig, **options):
+        """Install the requirements for the app dev.
+
+        This will always include test requirements, if specified.
 
         :param app: The config object for the app
         """
-        if app.requires:
-            with self.input.wait_bar("Installing dev dependencies..."):
+        requires = app.requires if app.requires else []
+        if app.test_requires:
+            requires.extend(app.test_requires)
+
+        if requires:
+            with self.input.wait_bar("Installing dev requirements..."):
                 try:
                     self.tools.subprocess.run(
                         [
@@ -71,57 +84,81 @@ class DevCommand(BaseCommand):
                             "install",
                             "--upgrade",
                         ]
-                        + app.requires,
+                        + requires,
                         check=True,
                     )
                 except subprocess.CalledProcessError as e:
-                    raise DependencyInstallError() from e
+                    raise RequirementsInstallError() from e
         else:
-            self.logger.info("No application dependencies.")
+            self.logger.info("No application requirements.")
 
-    def run_dev_app(self, app: BaseConfig, env: dict, **options):
+    def run_dev_app(
+        self,
+        app: BaseConfig,
+        env: dict,
+        test_mode: bool,
+        **options,
+    ):
         """Run the app in the dev environment.
 
         :param app: The config object for the app
         :param env: environment dictionary for sub command
+        :param test_mode: Run the test suite, rather than the app?
         """
-        try:
-            # Invoke the app.
-            self.tools.subprocess.run(
-                [
-                    sys.executable,
-                    "-u",
-                    "-c",
-                    (
-                        "import runpy, sys;"
-                        "sys.path.pop(0);"
-                        f'runpy.run_module("{app.module_name}", run_name="__main__", alter_sys=True)'
-                    ),
-                ],
-                env=env,
-                check=True,
-                cwd=self.tools.home_path,
-                stream_output=True,
-            )
-        except subprocess.CalledProcessError as e:
-            raise BriefcaseCommandError(
-                f"Unable to start application '{app.app_name}'"
-            ) from e
+        main_module = app.main_module(test_mode)
+        app_popen = self.tools.subprocess.Popen(
+            [
+                sys.executable,
+                "-u",
+                "-X",
+                "dev",
+                "-X",
+                "utf8",
+                "-c",
+                (
+                    "import runpy, sys;"
+                    "sys.path.pop(0);"
+                    f'runpy.run_module("{main_module}", run_name="__main__", alter_sys=True)'
+                ),
+            ],
+            env=env,
+            cwd=self.tools.home_path,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            bufsize=1,
+        )
 
-    def get_environment(self, app):
+        # Start streaming logs for the app.
+        self._stream_app_logs(
+            app,
+            popen=app_popen,
+            test_mode=test_mode,
+            clean_output=False,
+        )
+
+    def get_environment(self, app, test_mode: bool):
         # Create a shell environment where PYTHONPATH points to the source
         # directories described by the app config.
-        return {
+        env = {
             "PYTHONPATH": os.pathsep.join(
-                os.fsdecode(Path.cwd() / path) for path in app.PYTHONPATH
+                os.fsdecode(Path.cwd() / path) for path in app.PYTHONPATH(test_mode)
             )
         }
 
+        # On Windows, we need to disable the debug allocator because it
+        # conflicts with Python.net. See
+        # https://github.com/pythonnet/pythonnet/issues/1977 for details.
+        if self.platform == "windows":
+            env["PYTHONMALLOC"] = "default"
+
+        return env
+
     def __call__(
         self,
         appname: Optional[str] = None,
-        update_dependencies: Optional[bool] = False,
+        update_requirements: Optional[bool] = False,
         run_app: Optional[bool] = True,
+        test_mode: Optional[bool] = False,
         **options,
     ):
         # Confirm all required tools are available
@@ -148,21 +185,26 @@ class DevCommand(BaseCommand):
         self.verify_app_tools(app)
 
         # Look for the existence of a dist-info file.
-        # If one exists, assume that the dependencies have already been
+        # If one exists, assume that the requirements have already been
         # installed. If a dependency update has been manually requested,
         # do it regardless.
         dist_info_path = (
             self.app_module_path(app).parent / f"{app.module_name}.dist-info"
         )
         if not run_app:
-            # If we are not running the app, it means we should update dependencies.
-            update_dependencies = True
-        if update_dependencies or not dist_info_path.exists():
-            self.logger.info("Installing dependencies...", prefix=app.app_name)
-            self.install_dev_dependencies(app, **options)
+            # If we are not running the app, it means we should update requirements.
+            update_requirements = True
+        if update_requirements or not dist_info_path.exists():
+            self.logger.info("Installing requirements...", prefix=app.app_name)
+            self.install_dev_requirements(app, **options)
             write_dist_info(app, dist_info_path)
 
         if run_app:
-            self.logger.info("Starting in dev mode...", prefix=app.app_name)
-            env = self.get_environment(app)
-            return self.run_dev_app(app, env, **options)
+            if test_mode:
+                self.logger.info(
+                    "Running test suite in dev environment...", prefix=app.app_name
+                )
+            else:
+                self.logger.info("Starting in dev mode...", prefix=app.app_name)
+            env = self.get_environment(app, test_mode=test_mode)
+            return self.run_dev_app(app, env, test_mode=test_mode, **options)
