@@ -7,14 +7,15 @@ from .base import BaseCommand, full_options
 
 class OpenCommand(BaseCommand):
     command = "open"
+    description = "Open an app in the build tool for the target platform."
 
-    def open_project(self, project_path):
+    def _open_app(self, app: BaseConfig):
         if self.tools.host_os == "Windows":
-            self.tools.os.startfile(project_path)
+            self.tools.os.startfile(self.project_path(app))
         elif self.tools.host_os == "Darwin":
-            self.tools.subprocess.Popen(["open", project_path])
+            self.tools.subprocess.Popen(["open", self.project_path(app)])
         else:
-            self.tools.subprocess.Popen(["xdg-open", project_path])
+            self.tools.subprocess.Popen(["xdg-open", self.project_path(app)])
 
     def open_app(self, app: BaseConfig, **options):
         """Open the project for an app.
@@ -33,7 +34,7 @@ class OpenCommand(BaseCommand):
             f"Opening {self.project_path(app).relative_to(self.base_path)}...",
             prefix=app.app_name,
         )
-        self.open_project(project_path)
+        self._open_app(app)
 
         return state
 
