@@ -9,15 +9,6 @@ class HelpText(BriefcaseError):
     an error."""
 
 
-class InfoHelpText(HelpText):
-    def __init__(self, msg):
-        super().__init__(error_code=0, skip_logfile=True)
-        self.msg = msg
-
-    def __str__(self):
-        return self.msg
-
-
 class NoCommandError(HelpText):
     def __init__(self, msg):
         super().__init__(error_code=-10, skip_logfile=True)
@@ -27,17 +18,6 @@ class NoCommandError(HelpText):
         return self.msg
 
 
-class ShowOutputFormats(InfoHelpText):
-    def __init__(self, platform, default, choices):
-        super().__init__(
-            f"Available formats for {platform}: {', '.join(sorted(choices))}\n"
-            f"Default format: {default}"
-        )
-        self.platform = platform
-        self.default = default
-        self.choices = choices
-
-
 class InvalidFormatError(BriefcaseError):
     def __init__(self, requested, choices):
         super().__init__(error_code=-21, skip_logfile=True)
@@ -45,7 +25,7 @@ class InvalidFormatError(BriefcaseError):
         self.choices = choices
 
     def __str__(self):
-        choices = ", ".join(sorted(self.choices))
+        choices = ", ".join(sorted(self.choices, key=str.lower))
         return f"Invalid format '{self.requested}'; (choose from: {choices})"
 
 
@@ -128,3 +108,8 @@ class CorruptToolError(BriefcaseCommandError):
 class CommandOutputParseError(BriefcaseCommandError):
     def __init__(self, parse_error):
         super().__init__(msg=f"Unable to parse command output: {parse_error}")
+
+
+class BriefcaseTestSuiteFailure(BriefcaseError):
+    def __init__(self):
+        super().__init__(error_code=1000, skip_logfile=True)
