@@ -1,3 +1,4 @@
+import json
 import os
 import re
 import shutil
@@ -13,6 +14,7 @@ from briefcase.exceptions import (
     InvalidDeviceError,
     MissingToolError,
 )
+from briefcase.integrations.base import Tool, ToolCache
 from briefcase.integrations.java import JDK
 
 DEVICE_NOT_FOUND = re.compile(r"^error: device '[^']*' not found")
@@ -36,11 +38,11 @@ this device as a deployment target.
         )
 
 
-class AndroidSDK:
+class AndroidSDK(Tool):
     name = "android_sdk"
     full_name = "Android SDK"
 
-    def __init__(self, tools, root_path):
+    def __init__(self, tools: ToolCache, root_path: Path):
         self.tools = tools
         self.dot_android_path = self.tools.home_path / ".android"
         self.root_path = root_path
@@ -128,8 +130,20 @@ class AndroidSDK:
             f"{self.tools.host_os} {self.tools.host_arch} hardware."
         )
 
+    @property
+    def DEFAULT_DEVICE_TYPE(self):
+        return "pixel"
+
+    @property
+    def DEFAULT_DEVICE_SKIN(self):
+        return "pixel_3a"
+
+    @property
+    def DEFAULT_SYSTEM_IMAGE(self):
+        return f"system-images;android-31;default;{self.emulator_abi}"
+
     @classmethod
-    def verify(cls, tools, install=True):
+    def verify(cls, tools: ToolCache, install=True):
         """Verify an Android SDK is available.
 
         If the ANDROID_SDK_ROOT environment variable is set, that location will
@@ -312,6 +326,7 @@ Delete {cmdline_tools_zip_path} and run briefcase again.
                 [os.fsdecode(self.sdkmanager_path), "--update"],
                 env=self.env,
                 check=True,
+                stream_output=False,
             )
         except subprocess.CalledProcessError as e:
             raise BriefcaseCommandError(
@@ -367,6 +382,7 @@ before you may use those tools.
                 [os.fsdecode(self.sdkmanager_path), "--licenses"],
                 env=self.env,
                 check=True,
+                stream_output=False,
             )
         except subprocess.CalledProcessError as e:
             raise BriefcaseCommandError(
@@ -419,6 +435,7 @@ connection.
                 ],
                 env=self.env,
                 check=True,
+                stream_output=False,
             )
         except subprocess.CalledProcessError as e:
             raise BriefcaseCommandError(
@@ -468,8 +485,9 @@ connection.
         try:
             skin = avd_config["skin.name"]
             skin_path = Path(avd_config["skin.path"])
-
-            if skin_path != Path("skins") / skin:
+            if skin_path == Path("_no_skin"):
+                self.tools.logger.debug("Emulator does not use a skin.")
+            elif skin_path != Path("skins") / skin:
                 self.tools.logger.warning(
                     f"""
 *************************************************************************
@@ -549,6 +567,7 @@ connection.
                 ],
                 env=self.env,
                 check=True,
+                stream_output=False,
             )
         except subprocess.CalledProcessError as e:
             raise BriefcaseCommandError(
@@ -602,8 +621,7 @@ connection.
             # Capture `stderr` so that if the process exits with failure, the
             # stderr data is in `e.output`.
             output = self.tools.subprocess.check_output(
-                [os.fsdecode(self.emulator_path), "-list-avds"],
-                stderr=subprocess.STDOUT,
+                [os.fsdecode(self.emulator_path), "-list-avds"]
             ).strip()
 
             # AVD names are returned one per line.
@@ -619,8 +637,7 @@ connection.
             # Capture `stderr` so that if the process exits with failure, the
             # stderr data is in `e.output`.
             output = self.tools.subprocess.check_output(
-                [os.fsdecode(self.adb_path), "devices", "-l"],
-                stderr=subprocess.STDOUT,
+                [os.fsdecode(self.adb_path), "devices", "-l"]
             ).strip()
 
             # Process the output of `adb devices -l`.
@@ -666,17 +683,43 @@ connection.
 
         Interrogates the system to get the list of available devices.
 
-        If the user has specified a device at the command line, that device
-        will be validated, and then automatically selected.
+        If the user has specified a device at the command line, that device will
+        be validated, and then automatically selected.
 
         :param device_or_avd: The device or AVD to target. Can be a physical
-            device id (a hex string), an emulator id ("emulator-5554"), or
-            an emulator AVD name ("@robotfriend"). If ``None``, the user will
-            be asked to select a device from the list available.
-        :returns: A tuple containing ``(device, name, avd)``. ``avd``
-            will only be provided if an emulator with that AVD is not currently
-            running. If ``device`` is null, a new emulator should be created.
+            device id (a hex string), an emulator id (``emulator-5554``), or an
+            emulator AVD name (``@robotfriend``), or a JSON payload describing
+            the properties of an emulator that will be created (e.g.,
+            ``'{"avd":"beePhone","device_type":"pixel","skin":"pixel_3a","system_image":"system-images;android-31;default;arm64-v8a"}'``)
+            If ``None``, the user will be asked to select a device from the list
+            available.
+        :returns: A tuple containing ``(device, name, avd)``. ``avd`` will only
+            be provided if an emulator with that AVD is not currently running.
+            If ``device`` is null, a new emulator should be created.
         """
+        # If the device_or_avd starts with "{", it's a definition for a new
+        # emulator to be created.
+        if device_or_avd and device_or_avd.startswith("{"):
+            try:
+                emulator_config = json.loads(device_or_avd)
+                emulators = set(self.emulators())
+
+                # If an emulator with this AVD already exists, use it
+                avd = emulator_config["avd"]
+                if avd not in emulators:
+                    self._create_emulator(**emulator_config)
+
+                return None, f"@{avd} (emulator)", avd
+            except json.JSONDecodeError as e:
+                raise BriefcaseCommandError(
+                    f"Unable to create emulator with definition {device_or_avd!r}"
+                ) from e
+            except KeyError:
+                raise BriefcaseCommandError("No AVD provided for new device.")
+            except TypeError as e:
+                property = str(e).split(" ")[-1]
+                raise BriefcaseCommandError(f"Unknown device property {property}.")
+
         # Get the list of attached devices (includes running emulators)
         running_devices = self.devices()
 
@@ -812,7 +855,7 @@ Use the -d/--device option to explicitly specify the device to use.
                 f"""
 In future, you can specify this device by running:
 
-    $ briefcase run android -d @{avd}
+    $ briefcase run android -d "@{avd}"
 """
             )
         elif device:
@@ -826,9 +869,10 @@ In future, you can specify this device by running:
 
         return device, name, avd
 
-    def create_emulator(self):
+    def create_emulator(self, use_defaults=False):
         """Create a new Android emulator.
 
+        :param use_defaults: Should the emulator be created with defaults?
         :returns: The AVD of the newly created emulator.
         """
         # Get the list of existing emulators
@@ -879,15 +923,59 @@ An emulator named '{avd}' already exists.
                 avd_is_invalid = False
 
         # TODO: Provide a list of options for device types with matching skins
-        device_type = "pixel"
-        skin = "pixel_3a"
+        device_type = self.DEFAULT_DEVICE_TYPE
+        skin = self.DEFAULT_DEVICE_SKIN
+
+        # TODO: Provide a list of options for system images.
+        system_image = self.DEFAULT_SYSTEM_IMAGE
+
+        self._create_emulator(
+            avd=avd,
+            device_type=device_type,
+            skin=skin,
+            system_image=system_image,
+        )
+
+        self.tools.logger.info(
+            f"""
+Android emulator '{avd}' created.
+
+In future, you can specify this device by running:
+
+    $ briefcase run android -d @{avd}
+"""
+        )
+
+        return avd
+
+    def _create_emulator(
+        self,
+        avd,
+        device_type=None,
+        skin=None,
+        system_image=None,
+    ):
+        """Internal method that does the actual work of creating the emulator.
+
+        AVD is the only required argument; all other arguments will assume
+        reasonable defaults.
+
+        :param avd: The AVD for the new emulator
+        :param device_type: The device type for the new emulator (e.g., "pixel")
+        :param skin: The skin for the new emulator to use (e.g., "pixel_3a")
+        :param system_image: The system image to use on the new emulator.
+            (e.g., "system-images;android-31;default;arm64-v8a")
+        """
+        if device_type is None:
+            device_type = self.DEFAULT_DEVICE_TYPE
+        if skin is None:
+            skin = self.DEFAULT_DEVICE_SKIN
+        if system_image is None:
+            system_image = self.DEFAULT_SYSTEM_IMAGE
 
         # Ensure the required skin is available.
         self.verify_emulator_skin(skin)
 
-        # TODO: Provide a list of options for system images.
-        system_image = f"system-images;android-31;default;{self.emulator_abi}"
-
         # Ensure the required system image is available.
         self.verify_system_image(system_image)
 
@@ -909,7 +997,6 @@ An emulator named '{avd}' already exists.
                         device_type,
                     ],
                     env=self.env,
-                    stderr=subprocess.STDOUT,
                 )
             except subprocess.CalledProcessError as e:
                 raise BriefcaseCommandError("Unable to create Android emulator") from e
@@ -929,18 +1016,6 @@ An emulator named '{avd}' already exists.
                 },
             )
 
-        self.tools.logger.info(
-            f"""
-Android emulator '{avd}' created.
-
-In future, you can specify this device by running:
-
-    $ briefcase run android -d @{avd}
-"""
-        )
-
-        return avd
-
     def avd_config(self, avd):
         """Obtain the AVD configuration as key-value pairs.
 
@@ -975,23 +1050,29 @@ In future, you can specify this device by running:
             for key, value in avd_config.items():
                 f.write(f"{key}={value}\n")
 
-    def start_emulator(self, avd):
+    def start_emulator(self, avd, extra_args=None):
         """Start an existing Android emulator.
 
         Returns when the emulator is booted and ready to accept apps.
 
         :param avd: The AVD of the device.
+        :param extra_args: Additional command line arguments to pass when
+            starting the emulator.
         """
         if avd not in set(self.emulators()):
             raise InvalidDeviceError("emulator AVD", avd)
 
+        if extra_args is None:
+            extra_args = []
+
         emulator_popen = self.tools.subprocess.Popen(
             [
                 os.fsdecode(self.emulator_path),
                 f"@{avd}",
                 "-dns-server",
                 "8.8.8.8",
-            ],
+            ]
+            + extra_args,
             env=self.env,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
@@ -999,6 +1080,27 @@ In future, you can specify this device by running:
             start_new_session=True,
         )
 
+        # wrap AVD name in quotes since '@' is a special char in PowerShell
+        emulator_command = " ".join(
+            f'"{arg}"' if arg.startswith("@") else arg
+            for arg in map(str, emulator_popen.args)
+        )
+
+        error_msg = (
+            "{prologue}"
+            + f"""
+
+Try starting the emulator manually by running:
+
+    $ {emulator_command}
+
+Resolve any problems you discover, then try running your app again. You may
+find this page helpful in diagnosing emulator problems.
+
+    https://developer.android.com/studio/run/emulator-acceleration#accel-vm
+"""
+        )
+
         # The boot process happens in 2 phases.
         # First, the emulator appears in the device list. However, it's
         # not ready until the boot process has finished. To determine
@@ -1013,18 +1115,9 @@ In future, you can specify this device by running:
                 while adb is None:
                     if emulator_popen.poll() is not None:
                         raise BriefcaseCommandError(
-                            f"""\
-Android emulator was unable to start!
-
-Try starting the emulator manually by running:
-
-    $ {' '.join(str(arg) for arg in emulator_popen.args)}
-
-Resolve any problems you discover, then try running your app again. You may
-find this page helpful in diagnosing emulator problems.
-
-    https://developer.android.com/studio/run/emulator-acceleration#accel-vm
-"""
+                            error_msg.format(
+                                prologue="Android emulator was unable to start!"
+                            )
                         )
 
                     for device, details in sorted(self.devices().items()):
@@ -1053,27 +1146,28 @@ find this page helpful in diagnosing emulator problems.
                     while not adb.has_booted():
                         if emulator_popen.poll() is not None:
                             raise BriefcaseCommandError(
-                                f"""\
-Android emulator was unable to boot!
-
-Try starting the emulator manually by running:
-
-    $ {' '.join(str(arg) for arg in emulator_popen.args)}
-
-Resolve any problems you discover, then try running your app again. You may
-find this page helpful in diagnosing emulator problems.
-
-    https://developer.android.com/studio/run/emulator-acceleration#accel-vm
-"""
+                                error_msg.format(
+                                    prologue="Android emulator was unable to boot!"
+                                )
                             )
 
                         # Try again in 2 seconds...
                         self.sleep(2)
-        except Exception:
+        except BaseException as e:
             # if the emulator exited, this should return its output immediately;
             # if it is still running, this will quickly time out and print nothing.
             with suppress(subprocess.TimeoutExpired):
                 self.tools.logger.info(emulator_popen.communicate(timeout=1)[0])
+
+            # Provide troubleshooting steps if user gives up on the emulator starting
+            if isinstance(e, KeyboardInterrupt):
+                self.tools.logger.warning()
+                self.tools.logger.warning(
+                    error_msg.format(
+                        prologue="Is the Android emulator not starting up properly?"
+                    )
+                )
+
             raise
 
         # Return the device ID and full name.
@@ -1081,7 +1175,7 @@ find this page helpful in diagnosing emulator problems.
 
 
 class ADB:
-    def __init__(self, tools, device):
+    def __init__(self, tools: ToolCache, device: str):
         """An API integration for the Android Debug Bridge (ADB).
 
         :param tools: ToolCache of available tools
@@ -1125,14 +1219,19 @@ class ADB:
                 f"Unable to determine if emulator {self.device} has booted."
             ) from e
 
-    def run(self, *arguments):
+    def run(self, *arguments, quiet=False):
         """Run a command on a device using Android debug bridge, `adb`. The
         device name is mandatory to ensure clarity in the case of multiple
         attached devices.
 
         :param arguments: List of strings to pass to `adb` as arguments.
-
-        Returns `adb` output on success; raises an exception on failure.
+        :param quiet: Should the invocation of this command be silent, and
+            *not* appear in the logs? This should almost always be False;
+            however, for some calls (most notably, calls that are called
+            frequently to evaluate the status of another process), logging can
+            be turned off so that log output isn't corrupted by thousands of
+            polling calls.
+        :returns: `adb` output on success; raises an exception on failure.
         """
         # The ADB integration operates on the basis of running commands before
         # checking that they are valid, then parsing output to notice errors.
@@ -1150,7 +1249,7 @@ class ADB:
                     (os.fsdecode(arg) if isinstance(arg, Path) else arg)
                     for arg in arguments
                 ],
-                stderr=subprocess.STDOUT,
+                quiet=quiet,
             )
         except subprocess.CalledProcessError as e:
             if any(DEVICE_NOT_FOUND.match(line) for line in e.output.split("\n")):
@@ -1234,7 +1333,34 @@ Activity class not found while starting app.
             ) from e
 
     def logcat(self, pid):
-        """Start tailing the adb log for the device."""
+        """Start following the adb log for the device.
+
+        :param pid: The PID whose logs you want to display.
+        :returns: A Popen object for the logcat call
+        """
+        return self.tools.subprocess.Popen(
+            [
+                os.fsdecode(self.tools.android_sdk.adb_path),
+                "-s",
+                self.device,
+                "logcat",
+                "--pid",  # This option is available since API level 24.
+                pid,
+            ]
+            # Filter out some noisy and useless tags.
+            + [f"{tag}:S" for tag in ["EGL_emulation"]],
+            env=self.tools.android_sdk.env,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            bufsize=1,
+        )
+
+    def logcat_tail(self, since=None):
+        """Show the tail of the logs for Python-like apps, starting from a
+        given timestamp.
+
+        :param since: The start time from which logs should be displayed
+        """
         try:
             self.tools.subprocess.run(
                 [
@@ -1242,31 +1368,56 @@ Activity class not found while starting app.
                     "-s",
                     self.device,
                     "logcat",
-                    "--pid",  # This option is available since API level 24.
-                    pid,
-                ]
-                # Filter out some noisy and useless tags.
-                + [f"{tag}:S" for tag in ["EGL_emulation"]],
+                    "-t",
+                    since.strftime("%m-%d %H:%M:%S.000000"),
+                    "-s",
+                    # This is a collection of log labels that should catch
+                    # most Python app output.
+                    "MainActivity:*",
+                    "stdio:*",
+                    "python.stdout:*",
+                    "AndroidRuntime:*",
+                ],
                 env=self.tools.android_sdk.env,
                 check=True,
-                stream_output=True,
             )
         except subprocess.CalledProcessError as e:
-            # If the user sends CTRL+C:
-            #  - on Windows, adb returns 0xC000013A (STATUS_CONTROL_C_EXIT)
-            #  - on Linux/macOS, adb returns -2.
-            # Exit normally since the user was instructed to use CTRL+C.
-            if e.returncode not in {-2, 0xC000013A}:
-                raise BriefcaseCommandError("Error starting ADB logcat.") from e
+            raise BriefcaseCommandError("Error starting ADB logcat.") from e
 
-    def pidof(self, package):
-        """Return the PID of the given app as a string, or None if it isn't
-        running."""
+    def pidof(self, package, **kwargs):
+        """Obtain the PID of a running app by package name.
+
+        :param package: The package ID for the application (e.g.,
+            ``org.beeware.tutorial``)
+        :returns: The PID of the given app as a string, or None if it isn't
+        running.
+        """
         # The pidof command is available since API level 24. The level 23 emulator image also
         # includes it, but it doesn't work correctly (it returns all processes).
         try:
             # Exit status is unreliable: some devices (e.g. Nexus 4) return 0 even when no
             # process was found.
-            return self.run("shell", "pidof", "-s", package).strip() or None
+            return self.run("shell", "pidof", "-s", package, **kwargs).strip() or None
         except subprocess.CalledProcessError:
             return None
+
+    def pid_exists(self, pid, **kwargs):
+        """Confirm if the PID exists on the emulator.
+
+        :param pid: The PID to check
+        :returns: True if the PID exists, False if it doesn't.
+        """
+        # Look for the existence of /proc/<PID> on the device filesystem.
+        # If that file exists, so does the process.
+        try:
+            self.run("shell", "test", "-e", f"/proc/{pid}", **kwargs)
+            return True
+        except subprocess.CalledProcessError:
+            return False
+
+    def kill(self):
+        """Stop the running Android emulator."""
+        try:
+            self.run("emu", "kill")
+        except subprocess.CalledProcessError as e:
+            raise BriefcaseCommandError("Error starting ADB logcat.") from e
