@@ -6,20 +6,25 @@ import subprocess
 import sys
 import threading
 import time
-from contextlib import suppress
 from functools import wraps
 from pathlib import Path
 
 import psutil
 
+from briefcase.config import AppConfig
 from briefcase.console import Log
 from briefcase.exceptions import CommandOutputParseError
+from briefcase.integrations.base import Tool, ToolCache
 
 
 class ParseError(Exception):
     """Raised by parser functions to signal parsing was unsuccessful."""
 
 
+class StopStreaming(Exception):
+    """Raised by streaming filters to terminate the stream."""
+
+
 def ensure_str(text):
     """Returns input text as a string."""
     return text.decode() if isinstance(text, bytes) else str(text)
@@ -51,7 +56,9 @@ def is_process_dead(pid: int):
 
 
 def get_process_id_by_command(
-    command_list: list = None, command: str = "", logger: Log = None
+    command_list: list = None,
+    command: str = "",
+    logger: Log = None,
 ):
     """Find a Process ID (PID) a by its command. If multiple processes are
     found, then the most recently created process ID is returned.
@@ -117,7 +124,10 @@ def ensure_console_is_safe(sub_method):
         # such as the Wait Bar can hide this message from the user.
         if sub.tools.host_os == "Windows":
             executable = str(args[0]).strip() if args else ""
-            remove_dynamic_elements = executable.lower().endswith(".bat")
+            remove_dynamic_elements |= executable.lower().endswith(".bat")
+
+        # Release control for commands that cannot be streamed.
+        remove_dynamic_elements |= kwargs.get("stream_output") is False
 
         # Run subprocess command with or without console control
         if remove_dynamic_elements:
@@ -129,11 +139,11 @@ def ensure_console_is_safe(sub_method):
     return inner
 
 
-class NativeAppContext:
+class NativeAppContext(Tool):
     """A wrapper around subprocess for use as an app-bound tool."""
 
     @classmethod
-    def verify(cls, tools, app):
+    def verify(cls, tools: ToolCache, app: AppConfig):
         """Make subprocess available as app-bound tool."""
         # short circuit since already verified and available
         if hasattr(tools[app], "app_context"):
@@ -143,11 +153,14 @@ class NativeAppContext:
         return tools[app].app_context
 
 
-class Subprocess:
+class Subprocess(Tool):
     """A wrapper around subprocess that can be used as a logging point for
     commands that are executed."""
 
-    def __init__(self, tools):
+    name = "subprocess"
+    full_name = "Subprocess"
+
+    def __init__(self, tools: ToolCache):
         self.tools = tools
         self._subprocess = subprocess
 
@@ -246,7 +259,7 @@ class Subprocess:
         return kwargs
 
     @classmethod
-    def verify(cls, tools):
+    def verify(cls, tools: ToolCache):
         """Make subprocess available in tool cache."""
         # short circuit since already verified and available
         if hasattr(tools, "subprocess"):
@@ -256,31 +269,120 @@ class Subprocess:
         return tools.subprocess
 
     @ensure_console_is_safe
-    def run(self, args, stream_output=False, **kwargs):
+    def run(self, args, stream_output=True, **kwargs):
         """A wrapper for subprocess.run().
 
-        :param args: args for subprocess.run()
-        :param stream_output: simulate run() while streaming the output to the console
-        :param kwargs: keywords args for subprocess.run()
+        This method implements the behavior of subprocess.run() with some
+        notable differences:
 
-        The behavior of this method is identical to subprocess.run(),
-        except for:
-         - If a Wait Bar is active and IO is not redirected, subprocess.run()
-           will be simulated so the output can be proxied via stream_output.
-         - If the `env` argument is provided, the current system environment
-           will be copied, and the contents of env overwritten into that
-           environment.
-         - The `text` argument is defaulted to True so all output is returned
-           as strings instead of bytes.
+          - The command's output is streamed if ``stream_output=True`` or if
+            dynamic console content such as the Wait Bar is active and I/O is
+            not redirected.
+          - If dynamic content is not active, ``stream_output=False`` will
+            disable streaming.
+          - If the ``env`` argument is provided, the current system environment
+            will be copied, and the contents of env overwritten into that
+            environment.
+          - The ``text`` argument is defaulted to True so all output is returned
+            as strings instead of bytes.
+
+        Output Streaming Primer
+        ~~~~~~~~~~~~~~~~~~~~~~~
+
+        What is output streaming?
+        -------------------------
+
+        When a command is invoked via ``subprocess.run()``, by default, its
+        stdout and stderr are connected directly to the console and the output
+        is presented to the user as though the command was invoked natively.
+        When output streaming is active, Briefcase reads the command's output
+        and prints it in to the console on behalf of the command.
+
+        Why is output streaming necessary?
+        ----------------------------------
+
+        Allowing commands to print directly to the console can provide superior
+        UX since it allows tools to provide their native experience to users.
+
+        However, a primary mechanism for providing support for Briefcase is
+        asking users to provide the log file when errors occur. Often, these
+        errors are raised by invoked commands; streaming the output of commands
+        allows Briefcase to capture that output and include it in the log file
+        as well as the console.
+
+        Additionally, the content of the console can become corrupted if other
+        processes print to the console while Rich's dynamic console elements
+        such as a Progress Bar are active. Streaming such output allows Rich to
+        maintain integrity of all the console content.
+
+        How does output streaming work?
+        -------------------------------
+
+        Streaming is activated when:
+
+          1. dynamic content such as the Wait Bar is active and I/O is not
+             redirected
+
+          2. the ``stream_output`` argument is ``True`` (as it is by default)
+
+        I/O is considered redirected when both ``stdout`` and ``stderr`` are
+        specified (e.g., when ``stdout`` and ``stderr`` are set
+        to``subprocess.PIPE`` so the output is available to the caller).
+
+        To facilitate streaming the output, ``stdout`` is set to
+        ``subprocess.PIPE``. If ``stderr`` is not specified by calling code,
+        then it is set to ``subprocess.STDOUT`` so it is interlaced with stdout
+        output.
+
+        The process is created for the command with ``Popen``, and a separate
+        thread is started for continuously reading and printing the stdout to
+        the console from the command process. It is necessary to read from
+        stdout in a thread because the read is uninterruptible; so, a user may
+        not be able to abort with CTRL-C.
+
+        When the process ends (or the user sends CTRL-C), a call is made to
+        ensure the command process terminates; this, in turn, ensures the thread
+        for streaming can properly exit its otherwise infinite loop. The calling
+        code is either returned a ``CompletedProcess`` object or
+        ``CalledProcessError`` could be raised.
+
+        Output streaming ultimately strives to simulate calling
+        ``subprocess.run()`` while proxying the command's output to the console.
+
+        When *not* to use output streaming?
+        -----------------------------------
+
+        When streaming is disabled, the command's output **WILL NOT** be
+        included the Briefcase log file. This makes troubleshooting difficult
+        and should be avoided. However, there are some situations where disabling
+        streaming is unavoidable.
+
+        Some commands use their own dynamic console content such as progress
+        bars, spinners, and other animations. When such output is streamed, its
+        quality can be significantly compromised and look terrible in the
+        console for users. If it is not possible to disable such output with
+        e.g. a flag for the command, then disabling streaming may be necessary.
+        As an example, the ``flatpak install`` command uses many animations.
+
+        If a command requires user input, do not use output streaming. The
+        output streaming implementation doesn't provide any facilities to send
+        input to the process and doesn't provide any special handling of stdin.
+        Additionally, when the command process prompts the user for input, that
+        doesn't always trigger ``readline()`` to return; so, the console may
+        actually end up waiting for user input before displaying a prompt to the
+        user. As an example, accepting Android SDK licenses requires user input.
+
+        :param args: args for subprocess.run()
+        :param stream_output: simulate run() while streaming the output to the
+            console. Set to False if the command requires user interaction.
+        :param kwargs: keyword args for subprocess.run()
+        :return: `CompletedProcess` for invoked process
         """
-        # If `stream_output` or dynamic screen content (e.g. the Wait Bar) is
-        # active and output is not redirected, use run with output streaming.
-        is_output_redirected = kwargs.get("capture_output") or (
-            kwargs.get("stdout") and kwargs.get("stderr")
-        )
-        if stream_output or (
-            self.tools.input.is_console_controlled and not is_output_redirected
-        ):
+
+        # Stream the output unless the caller explicitly disables it. When a
+        # caller sets stream_output=False, then ensure_console_is_safe() will
+        # disable any dynamic console elements while the command runs.
+        if stream_output:
             return self._run_and_stream_output(args, **kwargs)
 
         # Otherwise, invoke run() normally.
@@ -352,7 +454,7 @@ class Subprocess:
         return subprocess.CompletedProcess(args, return_code, stderr=stderr)
 
     @ensure_console_is_safe
-    def check_output(self, args, **kwargs):
+    def check_output(self, args, quiet=False, **kwargs):
         """A wrapper for subprocess.check_output()
 
         The behavior of this method is identical to
@@ -362,22 +464,37 @@ class Subprocess:
            environment.
          - The `text` argument is defaulted to True so all output
            is returned as strings instead of bytes.
+         - The `stderr` argument is defaulted to `stdout` so _all_ output is
+           returned and `stderr` isn't unexpectedly printed to the console.
+
+        :param quiet: Should the invocation of this command be silent, and
+            *not* appear in the logs? This should almost always be False;
+            however, for some calls (most notably, calls that are called
+            frequently to evaluate the status of another process), logging can
+            be turned off so that log output isn't corrupted by thousands of
+            polling calls.
         """
-        self._log_command(args)
-        self._log_cwd(kwargs.get("cwd"))
-        self._log_environment(kwargs.get("env"))
+        # if stderr isn't explicitly redirected, then send it to stdout.
+        kwargs.setdefault("stderr", subprocess.STDOUT)
+
+        if not quiet:
+            self._log_command(args)
+            self._log_cwd(kwargs.get("cwd"))
+            self._log_environment(kwargs.get("env"))
 
         try:
             cmd_output = self._subprocess.check_output(
                 [str(arg) for arg in args], **self.final_kwargs(**kwargs)
             )
         except subprocess.CalledProcessError as e:
-            self._log_output(e.output, e.stderr)
-            self._log_return_code(e.returncode)
+            if not quiet:
+                self._log_output(e.output, e.stderr)
+                self._log_return_code(e.returncode)
             raise
 
-        self._log_output(cmd_output)
-        self._log_return_code(0)
+        if not quiet:
+            self._log_output(cmd_output)
+            self._log_return_code(0)
         return cmd_output
 
     def parse_output(self, output_parser, args, **kwargs):
@@ -436,7 +553,13 @@ class Subprocess:
             [str(arg) for arg in args], **self.final_kwargs(**kwargs)
         )
 
-    def stream_output(self, label, popen_process, stop_func=lambda: False):
+    def stream_output(
+        self,
+        label,
+        popen_process,
+        stop_func=lambda: False,
+        filter_func=None,
+    ):
         """Stream the output of a Popen process until the process exits. If the
         user sends CTRL+C, the process will be terminated.
 
@@ -449,11 +572,16 @@ class Subprocess:
         :param popen_process: a running Popen process with output to print
         :param stop_func: a Callable that returns True when output streaming
             should stop and the popen_process should be terminated.
+        :param filter_func: a callable that will be invoked on every line
+            of output that is streamed. The function accepts the "raw" line
+            of input (stripped of any trailing newline); it returns a generator
+            that yields the filtered output that should be displayed to the user.
+            Can raise StopStreaming to terminate the output stream.
         """
         output_streamer = threading.Thread(
             name=f"{label} output streamer",
             target=self._stream_output_thread,
-            args=(popen_process,),
+            args=(popen_process, filter_func),
             daemon=True,
         )
         try:
@@ -478,23 +606,43 @@ class Subprocess:
                     "Log stream hasn't terminated; log output may be corrupted."
                 )
 
-    def _stream_output_thread(self, popen_process):
+    def _stream_output_thread(self, popen_process, filter_func):
         """Stream output for a Popen process in a Thread.
 
         :param popen_process: popen process to stream stdout
+        :param filter_func: a callable that will be invoked on every line
+            of output that is streamed; see ``stream_output`` for details.
         """
-        # ValueError is raised if stdout is unexpectedly closed.
-        # This can happen if the user starts spamming CTRL+C, for instance.
-        # Silently exit to avoid Python printing the exception to the console.
-        with suppress(ValueError):
+        try:
             while True:
-                # readline should always return at least a newline (ie \n)
-                # UNLESS the underlying process is exiting/gone; then "" is returned
-                output_line = ensure_str(popen_process.stdout.readline())
+                try:
+                    output_line = ensure_str(popen_process.stdout.readline())
+                except ValueError:
+                    # ValueError is raised if stdout is unexpectedly closed. This can
+                    # happen if the user starts spamming CTRL+C, for instance. Silently
+                    # exit to avoid Python printing the exception to the console.
+                    return
+
+                # readline should always return at least a newline (ie \n) UNLESS
+                # the underlying process is exiting/gone; then "" is returned.
                 if output_line:
-                    self.tools.logger.info(output_line)
+                    if filter_func:
+                        try:
+                            for filtered_output in filter_func(
+                                output_line.rstrip("\n")
+                            ):
+                                self.tools.logger.info(filtered_output)
+                        except StopStreaming:
+                            return
+                    else:
+                        self.tools.logger.info(output_line)
                 else:
                     return
+        except Exception as e:
+            self.tools.logger.error(
+                f"Error while streaming output: {e.__class__.__name__}: {e}"
+            )
+            self.tools.logger.capture_stacktrace("Output thread")
 
     def cleanup(self, label, popen_process):
         """Clean up after a Popen process, gracefully terminating if possible;
