@@ -2,36 +2,36 @@ import os
 import shutil
 from pathlib import Path
 
-from requests import exceptions as requests_exceptions
-
 from briefcase.exceptions import (
     BriefcaseCommandError,
     MissingToolError,
-    NetworkFailure,
     NonManagedToolError,
 )
+from briefcase.integrations.base import Tool, ToolCache
 
 WIX_DOWNLOAD_URL = "https://github.com/wixtoolset/wix3/releases/download/wix3112rtm/wix311-binaries.zip"
 
 
-class WiX:
+class WiX(Tool):
     name = "wix"
     full_name = "WiX"
 
-    def __init__(self, command, wix_home=None, bin_install=False):
+    def __init__(self, tools: ToolCache, wix_home: Path = None, bin_install=False):
         """Create a wrapper around a WiX install.
 
-        :param command: The command using the wrapper.
+        :param tools: ToolCache of available tools.
         :param wix_home: The path of the WiX installation.
         :param bin_install: Is the install a binaries-only install? A full
             MSI install of WiX has a `/bin` folder in the paths; a
             binaries-only install does not.
+        :returns: A valid WiX SDK wrapper. If WiX is not available, and was
+            not installed, raises MissingToolError.
         """
-        self.command = command
+        self.tools = tools
         if wix_home:
             self.wix_home = wix_home
         else:
-            self.wix_home = command.tools_path / "wix"
+            self.wix_home = tools.base_path / "wix"
         self.bin_install = bin_install
 
     @property
@@ -56,7 +56,7 @@ class WiX:
             return self.wix_home / "bin" / "candle.exe"
 
     @classmethod
-    def verify(cls, command, install=True):
+    def verify(cls, tools: ToolCache, install=True):
         """Verify that there is a WiX install available.
 
         If the WIX environment variable is set, that location will be checked
@@ -65,23 +65,25 @@ class WiX:
         If the location provided doesn't contain an SDK, or no location is provided,
         an SDK is downloaded.
 
-        :param command: The command making the verification request.
+        :param tools: ToolCache of available tools
         :param install: Should WiX be installed if it is not found?
-        :returns: A valid WiX SDK wrapper. If WiX is not available, and was
-            not installed, raises MissingToolError.
         """
-        if command.host_os != "Windows":
+        # short circuit since already verified and available
+        if hasattr(tools, "wix"):
+            return tools.wix
+
+        if tools.host_os != "Windows":
             raise BriefcaseCommandError(
                 "A Windows MSI installer can only be created on Windows."
             )
 
         # Look for the WIX environment variable
-        wix_env = command.os.environ.get("WIX")
+        wix_env = tools.os.environ.get("WIX")
         if wix_env:
             wix_home = Path(wix_env)
 
             # Set up the paths for the WiX executables we will use.
-            wix = WiX(command=command, wix_home=wix_home)
+            wix = WiX(tools=tools, wix_home=wix_home)
 
             if not wix.exists():
                 raise BriefcaseCommandError(
@@ -92,11 +94,11 @@ WiX Toolset. Current value: {wix_home!r}
                 )
 
         else:
-            wix = WiX(command=command, bin_install=True)
+            wix = WiX(tools=tools, bin_install=True)
 
             if not wix.exists():
                 if install:
-                    command.logger.info(
+                    tools.logger.info(
                         "The WiX toolset was not found; downloading and installing...",
                         prefix=cls.name,
                     )
@@ -104,6 +106,7 @@ WiX Toolset. Current value: {wix_home!r}
                 else:
                     raise MissingToolError("WiX")
 
+        tools.wix = wix
         return wix
 
     def exists(self):
@@ -119,26 +122,25 @@ WiX Toolset. Current value: {wix_home!r}
             # Determine if wix_home is relative to the briefcase data directory.
             # If wix_home isn't inside this directory, this will raise a ValueError,
             # indicating it is a non-managed install.
-            self.wix_home.relative_to(self.command.tools_path)
+            self.wix_home.relative_to(self.tools.base_path)
             return True
         except ValueError:
             return False
 
     def install(self):
         """Download and install WiX."""
-        try:
-            wix_zip_path = self.command.download_url(
-                url=WIX_DOWNLOAD_URL,
-                download_path=self.command.tools_path,
-            )
-        except requests_exceptions.ConnectionError as e:
-            raise NetworkFailure("download WiX") from e
+        wix_zip_path = self.tools.download.file(
+            url=WIX_DOWNLOAD_URL,
+            download_path=self.tools.base_path,
+            role="WiX",
+        )
 
         try:
-            with self.command.input.wait_bar("Installing WiX..."):
+            with self.tools.input.wait_bar("Installing WiX..."):
                 # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
-                self.command.shutil.unpack_archive(
-                    os.fsdecode(wix_zip_path), extract_dir=os.fsdecode(self.wix_home)
+                self.tools.shutil.unpack_archive(
+                    os.fsdecode(wix_zip_path),
+                    extract_dir=os.fsdecode(self.wix_home),
                 )
         except (shutil.ReadError, EOFError) as e:
             raise BriefcaseCommandError(
@@ -155,8 +157,8 @@ Delete {wix_zip_path} and run briefcase again.
 
     def uninstall(self):
         """Uninstall WiX."""
-        with self.command.input.wait_bar("Removing old WiX install..."):
-            self.command.shutil.rmtree(self.wix_home)
+        with self.tools.input.wait_bar("Removing old WiX install..."):
+            self.tools.shutil.rmtree(self.wix_home)
 
     def upgrade(self):
         """Upgrade an existing WiX install."""
