@@ -4,6 +4,7 @@ import subprocess
 from pathlib import Path
 
 from briefcase.exceptions import BriefcaseCommandError, CommandOutputParseError
+from briefcase.integrations.base import ToolCache
 from briefcase.integrations.subprocess import json_parser
 
 
@@ -14,7 +15,7 @@ class DeviceState(enum.Enum):
     UNKNOWN = 99
 
 
-def verify_xcode_install(tools, min_version=None):
+def verify_xcode_install(tools: ToolCache, min_version: tuple = None):
     """Verify that Xcode and the command line developer tools are installed and
     ready for use.
 
@@ -43,7 +44,7 @@ def verify_xcode_install(tools, min_version=None):
     tools.xcode = True
 
 
-def verify_command_line_tools_install(tools):
+def verify_command_line_tools_install(tools: ToolCache):
     """Verify that command line developer tools are installed and ready for
     use.
 
@@ -64,7 +65,7 @@ def verify_command_line_tools_install(tools):
     tools.xcode_cli = True
 
 
-def ensure_command_line_tools_are_installed(tools):
+def ensure_command_line_tools_are_installed(tools: ToolCache):
     """Determine if the Xcode command line tools are installed.
 
     If they are not installed, an exception is raised; in addition, an OS dialog
@@ -84,10 +85,7 @@ def ensure_command_line_tools_are_installed(tools):
     #
     # Any other status code is a problem.
     try:
-        tools.subprocess.check_output(
-            ["xcode-select", "--install"],
-            stderr=subprocess.STDOUT,
-        )
+        tools.subprocess.check_output(["xcode-select", "--install"])
         raise BriefcaseCommandError(
             """\
 Xcode command line developer tools are not installed.
@@ -126,8 +124,8 @@ Re-run Briefcase once that installation is complete.
 
 
 def ensure_xcode_is_installed(
-    tools,
-    min_version=None,
+    tools: ToolCache,
+    min_version: tuple = None,
     xcode_location="/Applications/Xcode.app",
 ):
     """Determine if Xcode is installed; and if so, that it meets minimum
@@ -147,10 +145,7 @@ def ensure_xcode_is_installed(
     #  * The path to the currently active Xcode install; or
     #  * error code 2 - No Xcode installation
     try:
-        tools.subprocess.check_output(
-            ["xcode-select", "-p"],
-            stderr=subprocess.STDOUT,
-        )
+        tools.subprocess.check_output(["xcode-select", "-p"])
     except subprocess.CalledProcessError as e:
         raise BriefcaseCommandError(
             """\
@@ -172,10 +167,7 @@ you can re-run Briefcase.
         #   xcode-select: error: tool 'xcodebuild' requires Xcode, but active
         #   developer directory '/Library/Developer/CommandLineTools' is a
         #   command line tools instance
-        output = tools.subprocess.check_output(
-            ["xcodebuild", "-version"],
-            stderr=subprocess.STDOUT,
-        )
+        output = tools.subprocess.check_output(["xcodebuild", "-version"])
 
         if min_version is not None:
             # Look for a line in the output that reads "Xcode X.Y.Z"
@@ -275,7 +267,7 @@ installation is complete.
             ) from e
 
 
-def confirm_xcode_license_accepted(tools):
+def confirm_xcode_license_accepted(tools: ToolCache):
     """Confirm if the Xcode license has been accepted.
 
     :param tools: ToolCache of available tools
@@ -284,10 +276,7 @@ def confirm_xcode_license_accepted(tools):
     # tools return a status code of 69 (nice...) if the license has not been
     # accepted. In this case, we can prompt the user to accept the license.
     try:
-        tools.subprocess.check_output(
-            ["/usr/bin/clang", "--version"],
-            stderr=subprocess.STDOUT,
-        )
+        tools.subprocess.check_output(["/usr/bin/clang", "--version"])
     except subprocess.CalledProcessError as e:
         if e.returncode == 69:
             tools.logger.info(
@@ -310,6 +299,7 @@ to enter your password (Briefcase will not store this password anywhere).
                 tools.subprocess.run(
                     ["sudo", "xcodebuild", "-license"],
                     check=True,
+                    stream_output=False,
                 )
             except subprocess.CalledProcessError as e:
                 # status code 1 - sudo fail
@@ -381,8 +371,8 @@ You need to accept the Xcode license before Briefcase can package your app.
 
 
 def get_simulators(
-    tools,
-    os_name,
+    tools: ToolCache,
+    os_name: str,
     simulator_location="/Library/Developer/PrivateFrameworks/CoreSimulator.framework/",
 ):
     """Obtain the simulators available on this machine.
@@ -457,7 +447,7 @@ Press Return to continue: """
         raise BriefcaseCommandError("Unable to run xcrun simctl.") from e
 
 
-def get_device_state(tools, udid):
+def get_device_state(tools: ToolCache, udid: str):
     """Determine the state of an iOS simulator device.
 
     :param tools: ToolCache of available tools
@@ -492,7 +482,7 @@ def get_device_state(tools, udid):
 IDENTITY_RE = re.compile(r"\s*\d+\) ([0-9A-F]{40}) \"(.*)\"")
 
 
-def get_identities(tools, policy):
+def get_identities(tools: ToolCache, policy: str):
     """Obtain a set of valid identities for the given policy.
 
     :param tools: ToolCache of available tools
