@@ -31,9 +31,6 @@ class macOSAppMixin(macOSMixin):
         else:
             return self.binary_path(app)
 
-    def entitlements_path(self, app):
-        return self.bundle_path(app) / "Entitlements.plist"
-
 
 class macOSAppCreateCommand(macOSAppMixin, CreateCommand):
     description = "Create and populate a macOS app."
@@ -44,7 +41,7 @@ class macOSAppUpdateCommand(macOSAppCreateCommand, UpdateCommand):
 
 
 class macOSAppOpenCommand(macOSAppMixin, OpenCommand):
-    description = "Open the app bundle folder for a macOS app."
+    description = "Open the app bundle folder for an existing macOS app."
 
 
 class macOSAppBuildCommand(macOSAppMixin, macOSSigningMixin, BuildCommand):
