@@ -1,7 +1,7 @@
 import subprocess
 from pathlib import Path
 
-from briefcase.commands import BuildCommand, PublishCommand, UpdateCommand
+from briefcase.commands import BuildCommand, OpenCommand, PublishCommand, UpdateCommand
 from briefcase.config import BaseConfig
 from briefcase.exceptions import BriefcaseCommandError
 from briefcase.integrations.rcedit import RCEdit
@@ -17,21 +17,28 @@ class WindowsAppMixin(WindowsMixin):
     output_format = "app"
     packaging_root = Path("src")
 
+    def project_path(self, app):
+        return self.bundle_path(app)
+
 
 class WindowsAppCreateCommand(WindowsAppMixin, WindowsCreateCommand):
     description = "Create and populate a Windows app."
 
 
-class WindowsAppUpdateCommand(WindowsAppMixin, UpdateCommand):
+class WindowsAppUpdateCommand(WindowsAppCreateCommand, UpdateCommand):
     description = "Update an existing Windows app."
 
 
+class WindowsAppOpenCommand(WindowsAppMixin, OpenCommand):
+    description = "Open the folder containing an existing Windows app."
+
+
 class WindowsAppBuildCommand(WindowsAppMixin, BuildCommand):
     description = "Build a Windows app."
 
     def verify_tools(self):
         super().verify_tools()
-        self.rcedit = RCEdit.verify(self)
+        RCEdit.verify(tools=self.tools)
 
     def build_app(self, app: BaseConfig, **kwargs):
         """Build the application.
@@ -42,9 +49,9 @@ class WindowsAppBuildCommand(WindowsAppMixin, BuildCommand):
 
         with self.input.wait_bar("Setting stub app details..."):
             try:
-                self.subprocess.run(
+                self.tools.subprocess.run(
                     [
-                        self.rcedit.rcedit_path,
+                        self.tools.rcedit.rcedit_path,
                         self.binary_path(app).relative_to(self.bundle_path(app)),
                         "--set-version-string",
                         "CompanyName",
@@ -87,16 +94,17 @@ class WindowsAppRunCommand(WindowsAppMixin, WindowsRunCommand):
 
 
 class WindowsAppPackageCommand(WindowsAppMixin, WindowsPackageCommand):
-    description = "Package a Windows App as an MSI."
+    description = "Package a Windows app as an MSI."
 
 
 class WindowsAppPublishCommand(WindowsAppMixin, PublishCommand):
-    description = "Publish a Windows App."
+    description = "Publish a Windows app."
 
 
 # Declare the briefcase command bindings
 create = WindowsAppCreateCommand  # noqa
 update = WindowsAppUpdateCommand  # noqa
+open = WindowsAppOpenCommand  # noqa
 build = WindowsAppBuildCommand  # noqa
 run = WindowsAppRunCommand  # noqa
 package = WindowsAppPackageCommand  # noqa
