@@ -8,7 +8,7 @@ from briefcase.commands.base import TemplateUnsupportedVersion, cookiecutter_cac
 
 def test_non_url(base_command, mock_git):
     """If the provided template isn't a URL, don't try to update."""
-    base_command.git = mock_git
+    base_command.tools.git = mock_git
 
     cached_template = base_command.update_cookiecutter_cache(
         template="/path/to/template",
@@ -17,16 +17,16 @@ def test_non_url(base_command, mock_git):
 
     assert cached_template == "/path/to/template"
     # No git actions are performed
-    assert base_command.git.Repo.call_count == 0
+    assert base_command.tools.git.Repo.call_count == 0
 
 
 def test_explicit_new_repo_template(base_command, mock_git):
     """If a previously unknown URL template is specified it is used."""
-    base_command.git = mock_git
+    base_command.tools.git = mock_git
 
     # There won't be a cookiecutter cache, so there won't be
     # a repo path (yet).
-    base_command.git.Repo.side_effect = git_exceptions.NoSuchPathError
+    base_command.tools.git.Repo.side_effect = git_exceptions.NoSuchPathError
 
     cached_path = cookiecutter_cache_path(
         "https://example.com/magic/special-template.git"
@@ -42,12 +42,37 @@ def test_explicit_new_repo_template(base_command, mock_git):
     assert cached_template == "https://example.com/magic/special-template.git"
 
     # The cookiecutter cache location will be interrogated.
-    base_command.git.Repo.assert_called_once_with(cached_path)
+    base_command.tools.git.Repo.assert_called_once_with(cached_path)
+
+
+def test_explicit_invalid_repo_template(base_command, mock_git):
+    """If a previously known URL template is cached, but isn't a git
+    repository, it is used as-is."""
+    base_command.tools.git = mock_git
+
+    # Return an error from updating the template
+    base_command.tools.git.Repo.side_effect = git_exceptions.InvalidGitRepositoryError
+
+    cached_path = cookiecutter_cache_path(
+        "https://example.com/magic/special-template.git"
+    )
+
+    # Update the cache
+    cached_template = base_command.update_cookiecutter_cache(
+        template="https://example.com/magic/special-template.git",
+        branch="special",
+    )
+
+    # The template that will be used is the original URL
+    assert cached_template == "https://example.com/magic/special-template.git"
+
+    # The cookiecutter cache location will be interrogated.
+    base_command.tools.git.Repo.assert_called_once_with(cached_path)
 
 
 def test_explicit_cached_repo_template(base_command, mock_git):
     """If a previously known URL template is specified it is used."""
-    base_command.git = mock_git
+    base_command.tools.git = mock_git
 
     mock_repo = mock.MagicMock()
     mock_remote = mock.MagicMock()
@@ -55,7 +80,7 @@ def test_explicit_cached_repo_template(base_command, mock_git):
 
     # Git returns a Repo, that repo can return a remote, and it has
     # heads that can be accessed.
-    base_command.git.Repo.return_value = mock_repo
+    base_command.tools.git.Repo.return_value = mock_repo
     mock_repo.remote.return_value = mock_remote
     mock_remote.refs.__getitem__.return_value = mock_remote_head
 
@@ -70,7 +95,7 @@ def test_explicit_cached_repo_template(base_command, mock_git):
     )
 
     # The cookiecutter cache location will be interrogated.
-    base_command.git.Repo.assert_called_once_with(cached_path)
+    base_command.tools.git.Repo.assert_called_once_with(cached_path)
 
     # The origin of the repo was fetched
     mock_repo.remote.assert_called_once_with(name="origin")
@@ -89,7 +114,7 @@ def test_explicit_cached_repo_template(base_command, mock_git):
 def test_offline_repo_template(base_command, mock_git):
     """If the user is offline the first time a repo template is requested, an
     error is raised."""
-    base_command.git = mock_git
+    base_command.tools.git = mock_git
 
     mock_repo = mock.MagicMock()
     mock_remote = mock.MagicMock()
@@ -98,7 +123,7 @@ def test_offline_repo_template(base_command, mock_git):
     # Git returns a Repo, that repo can return a remote, and it has
     # heads that can be accessed. However, calling fetch on the remote
     # will cause a git error (error code 128).
-    base_command.git.Repo.return_value = mock_repo
+    base_command.tools.git.Repo.return_value = mock_repo
     mock_repo.remote.return_value = mock_remote
     mock_remote.refs.__getitem__.return_value = mock_remote_head
     mock_remote.fetch.side_effect = git_exceptions.GitCommandError("git", 128)
@@ -113,7 +138,7 @@ def test_offline_repo_template(base_command, mock_git):
     )
 
     # The cookiecutter cache location will be interrogated.
-    base_command.git.Repo.assert_called_once_with(cached_path)
+    base_command.tools.git.Repo.assert_called_once_with(cached_path)
 
     # The origin of the repo was fetched
     mock_repo.remote.assert_called_once_with(name="origin")
@@ -132,7 +157,7 @@ def test_offline_repo_template(base_command, mock_git):
 def test_cached_missing_branch_template(base_command, mock_git):
     """If the cached repo doesn't have the requested branch, an error is
     raised."""
-    base_command.git = mock_git
+    base_command.tools.git = mock_git
 
     mock_repo = mock.MagicMock()
     mock_remote = mock.MagicMock()
@@ -140,7 +165,7 @@ def test_cached_missing_branch_template(base_command, mock_git):
     # Git returns a Repo, that repo can return a remote. However, it doesn't
     # have a head corresponding to the requested Python version, so it
     # raises an IndexError
-    base_command.git.Repo.return_value = mock_repo
+    base_command.tools.git.Repo.return_value = mock_repo
     mock_repo.remote.return_value = mock_remote
     mock_remote.refs.__getitem__.side_effect = IndexError
 
@@ -151,11 +176,12 @@ def test_cached_missing_branch_template(base_command, mock_git):
     # Generating the template under there conditions raises an error
     with pytest.raises(TemplateUnsupportedVersion):
         base_command.update_cookiecutter_cache(
-            template="https://example.com/magic/special-template.git", branch="invalid"
+            template="https://example.com/magic/special-template.git",
+            branch="invalid",
         )
 
     # The cookiecutter cache location will be interrogated.
-    base_command.git.Repo.assert_called_once_with(cached_path)
+    base_command.tools.git.Repo.assert_called_once_with(cached_path)
 
     # The origin of the repo was fetched
     mock_repo.remote.assert_called_once_with(name="origin")
