@@ -52,9 +52,9 @@ def test_no_code(
 
     myapp.sources = None
 
-    create_command.install_app_code(myapp)
+    create_command.install_app_code(myapp, test_mode=False)
 
-    # No request was made to install dependencies
+    # No request was made to install requirements
     create_command.tools.shutil.rmtree.assert_called_once_with(app_path)
     create_command.tools.os.mkdir.assert_called_once_with(app_path)
     create_command.tools.shutil.copytree.assert_not_called()
@@ -78,9 +78,9 @@ def test_empty_code(
 
     myapp.sources = []
 
-    create_command.install_app_code(myapp)
+    create_command.install_app_code(myapp, test_mode=False)
 
-    # No request was made to install dependencies
+    # No request was made to install requirements
     create_command.tools.shutil.rmtree.assert_called_once_with(app_path)
     create_command.tools.os.mkdir.assert_called_once_with(app_path)
     create_command.tools.shutil.copytree.assert_not_called()
@@ -101,7 +101,7 @@ def test_source_missing(
     myapp.sources = ["missing"]
 
     with pytest.raises(MissingAppSources):
-        create_command.install_app_code(myapp)
+        create_command.install_app_code(myapp, test_mode=False)
 
     # Distinfo won't be created.
     dist_info_path = app_path / "myapp-1.2.3.dist-info"
@@ -141,7 +141,7 @@ def test_source_dir(
     # Set the app definition, and install sources
     myapp.sources = ["src/first", "src/second"]
 
-    create_command.install_app_code(myapp)
+    create_command.install_app_code(myapp, test_mode=False)
 
     # All the sources exist.
     assert (app_path / "first").exists()
@@ -156,6 +156,10 @@ def test_source_dir(
     # Metadata has been created
     assert_dist_info(app_path)
 
+    # Original app definitions haven't changed
+    assert myapp.sources == ["src/first", "src/second"]
+    assert myapp.test_sources is None
+
 
 def test_source_file(
     create_command,
@@ -181,7 +185,7 @@ def test_source_file(
     # Set the app definition, and install sources
     myapp.sources = ["src/demo.py", "other.py"]
 
-    create_command.install_app_code(myapp)
+    create_command.install_app_code(myapp, test_mode=False)
 
     # All the sources exist.
     assert (app_path / "demo.py").exists()
@@ -190,6 +194,10 @@ def test_source_file(
     # Metadata has been created
     assert_dist_info(app_path)
 
+    # Original app definitions haven't changed
+    assert myapp.sources == ["src/demo.py", "other.py"]
+    assert myapp.test_sources is None
+
 
 def test_no_existing_app_folder(
     create_command,
@@ -226,7 +234,7 @@ def test_no_existing_app_folder(
     # Set the app definition, and install sources
     myapp.sources = ["src/first/demo.py", "src/second"]
 
-    create_command.install_app_code(myapp)
+    create_command.install_app_code(myapp, test_mode=False)
 
     # All the new sources exist, and contain the new content.
     assert (app_path / "demo.py").exists()
@@ -252,6 +260,10 @@ def test_no_existing_app_folder(
     assert not (app_path / "my_app-1.2.2.dist-info").exists()
     assert_dist_info(app_path)
 
+    # Original app definitions haven't changed
+    assert myapp.sources == ["src/first/demo.py", "src/second"]
+    assert myapp.test_sources is None
+
 
 def test_replace_sources(
     create_command,
@@ -325,7 +337,7 @@ def test_replace_sources(
     # Set the app definition, and install sources
     myapp.sources = ["src/first/demo.py", "src/second"]
 
-    create_command.install_app_code(myapp)
+    create_command.install_app_code(myapp, test_mode=False)
 
     # All the new sources exist, and contain the new content.
     assert (app_path / "demo.py").exists()
@@ -351,6 +363,10 @@ def test_replace_sources(
     assert not (app_path / "my_app-1.2.2.dist-info").exists()
     assert_dist_info(app_path)
 
+    # Original app definitions haven't changed
+    assert myapp.sources == ["src/first/demo.py", "src/second"]
+    assert myapp.test_sources is None
+
 
 def test_non_latin_metadata(
     create_command,
@@ -372,9 +388,9 @@ def test_non_latin_metadata(
 
     myapp.sources = []
 
-    create_command.install_app_code(myapp)
+    create_command.install_app_code(myapp, test_mode=False)
 
-    # No request was made to install dependencies
+    # No request was made to install requirements
     create_command.tools.shutil.rmtree.assert_called_once_with(app_path)
     create_command.tools.os.mkdir.assert_called_once_with(app_path)
     create_command.tools.shutil.copytree.assert_not_called()
@@ -406,3 +422,220 @@ Author-email: 钱华林@中科院.中国
 Summary: A Møøse once bit my sister...
 """
         )
+
+
+def test_test_sources(
+    create_command,
+    myapp,
+    tmp_path,
+    app_path,
+    app_requirements_path_index,
+):
+    """If an app defines test code, but we're not in test mode, it isn't
+    copied."""
+    # Create the mock sources
+    # src /
+    #   first /
+    #     demo.py
+    #   second /
+    #     shallow.py
+    # tests /
+    #   first.py
+    #   deep /
+    #     test_case.py
+    # othertests/
+    #   tests_more.py
+    #   special /
+    #     test_weird.py
+    create_file(
+        tmp_path / "project" / "src" / "first" / "demo.py",
+        "print('hello first')\n",
+    )
+    create_file(
+        tmp_path / "project" / "src" / "second" / "shallow.py",
+        "print('hello shallow second')\n",
+    )
+    create_file(
+        tmp_path / "project" / "tests" / "first.py",
+        "print('hello first test suite')\n",
+    )
+    create_file(
+        tmp_path / "project" / "tests" / "deep" / "test_case.py",
+        "print('hello test case')\n",
+    )
+    create_file(
+        tmp_path / "project" / "othertests" / "test_more.py",
+        "print('hello more tests')\n",
+    )
+    create_file(
+        tmp_path / "project" / "othertests" / "special" / "test_weird.py",
+        "print('hello weird tests')\n",
+    )
+
+    # Set the app definition, and install sources
+    myapp.sources = ["src/first", "src/second"]
+    myapp.test_sources = ["tests", "othertests"]
+
+    create_command.install_app_code(myapp, test_mode=False)
+
+    # App sources exist.
+    assert (app_path / "first").exists()
+    assert (app_path / "first" / "demo.py").exists()
+
+    assert (app_path / "second").exists()
+    assert (app_path / "second" / "shallow.py").exists()
+
+    # Test sources do not exist
+    assert not (app_path / "tests").exists()
+    assert not (app_path / "othertests").exists()
+
+    # Metadata has been created
+    assert_dist_info(app_path)
+
+    # Original app definitions haven't changed
+    assert myapp.sources == ["src/first", "src/second"]
+    assert myapp.test_sources == ["tests", "othertests"]
+
+
+def test_test_sources_test_mode(
+    create_command,
+    myapp,
+    tmp_path,
+    app_path,
+    app_requirements_path_index,
+):
+    """If an app defines test code, and we're in test mode, test sources are
+    copied."""
+    # Create the mock sources
+    # src /
+    #   first /
+    #     demo.py
+    #   second /
+    #     shallow.py
+    # tests /
+    #   first.py
+    #   deep /
+    #     test_case.py
+    # othertests/
+    #   tests_more.py
+    #   special /
+    #     test_weird.py
+    create_file(
+        tmp_path / "project" / "src" / "first" / "demo.py",
+        "print('hello first')\n",
+    )
+    create_file(
+        tmp_path / "project" / "src" / "second" / "shallow.py",
+        "print('hello shallow second')\n",
+    )
+    create_file(
+        tmp_path / "project" / "tests" / "first.py",
+        "print('hello first test suite')\n",
+    )
+    create_file(
+        tmp_path / "project" / "tests" / "deep" / "test_case.py",
+        "print('hello test case')\n",
+    )
+    create_file(
+        tmp_path / "project" / "othertests" / "test_more.py",
+        "print('hello more tests')\n",
+    )
+    create_file(
+        tmp_path / "project" / "othertests" / "special" / "test_weird.py",
+        "print('hello weird tests')\n",
+    )
+
+    # Set the app definition, and install sources
+    myapp.sources = ["src/first", "src/second"]
+    myapp.test_sources = ["tests", "othertests"]
+
+    create_command.install_app_code(myapp, test_mode=True)
+
+    # App sources exist.
+    assert (app_path / "first").exists()
+    assert (app_path / "first" / "demo.py").exists()
+
+    assert (app_path / "second").exists()
+    assert (app_path / "second" / "shallow.py").exists()
+
+    # Test sources exist
+    assert (app_path / "tests" / "first.py").exists()
+    assert (app_path / "tests" / "deep" / "test_case.py").exists()
+
+    assert (app_path / "othertests" / "test_more.py").exists()
+    assert (app_path / "othertests" / "special" / "test_weird.py").exists()
+
+    # Metadata has been created
+    assert_dist_info(app_path)
+
+    # Original app definitions haven't changed
+    assert myapp.sources == ["src/first", "src/second"]
+    assert myapp.test_sources == ["tests", "othertests"]
+
+
+def test_only_test_sources_test_mode(
+    create_command,
+    myapp,
+    tmp_path,
+    app_path,
+    app_requirements_path_index,
+):
+    """If an app only defines test code, and we're in test mode, test sources
+    are copied."""
+    # Create the mock sources
+    # tests /
+    #   first.py
+    #   deep /
+    #     test_case.py
+    # othertests/
+    #   tests_more.py
+    #   special /
+    #     test_weird.py
+    create_file(
+        tmp_path / "project" / "src" / "first" / "demo.py",
+        "print('hello first')\n",
+    )
+    create_file(
+        tmp_path / "project" / "src" / "second" / "shallow.py",
+        "print('hello shallow second')\n",
+    )
+    create_file(
+        tmp_path / "project" / "tests" / "first.py",
+        "print('hello first test suite')\n",
+    )
+    create_file(
+        tmp_path / "project" / "tests" / "deep" / "test_case.py",
+        "print('hello test case')\n",
+    )
+    create_file(
+        tmp_path / "project" / "othertests" / "test_more.py",
+        "print('hello more tests')\n",
+    )
+    create_file(
+        tmp_path / "project" / "othertests" / "special" / "test_weird.py",
+        "print('hello weird tests')\n",
+    )
+
+    # Set the app definition, and install sources
+    myapp.sources = None
+    myapp.test_sources = ["tests", "othertests"]
+
+    create_command.install_app_code(myapp, test_mode=True)
+
+    # App sources do not exist.
+    assert not (app_path / "first").exists()
+    assert not (app_path / "second").exists()
+
+    # Test sources exist
+    assert (app_path / "tests" / "first.py").exists()
+    assert (app_path / "tests" / "deep" / "test_case.py").exists()
+
+    assert (app_path / "othertests" / "test_more.py").exists()
+    assert (app_path / "othertests" / "special" / "test_weird.py").exists()
+
+    # Metadata has been created
+    assert_dist_info(app_path)
+
+    # Original app definitions haven't changed
+    assert myapp.sources is None
+    assert myapp.test_sources == ["tests", "othertests"]
