@@ -4,12 +4,14 @@ import pytest
 
 from briefcase.commands import DevCommand
 from briefcase.config import AppConfig
+from briefcase.console import Console, Log
+from briefcase.integrations.subprocess import Subprocess
 
 
 @pytest.fixture
 def dev_command(tmp_path):
-    command = DevCommand(base_path=tmp_path)
-    command.subprocess = mock.MagicMock()
+    command = DevCommand(logger=Log(), console=Console(), base_path=tmp_path)
+    command.tools.subprocess = mock.MagicMock(spec_set=Subprocess)
     return command
 
 
@@ -72,4 +74,5 @@ def third_app(tmp_path):
         version="0.0.2",
         description="The third simple app",
         sources=["src/third", "src/common", "other"],
+        test_sources=["tests", "path/to/other"],
     )
