@@ -24,11 +24,12 @@ def new_command(tmp_path):
     "briefcase_version, expected_branch",
     [
         ("37.42.1", "v37.42.1"),
-        ("37.42.2.dev73+gad61a29.d20220919", "v37.42.2"),
-        ("37.42.3a1", "v37.42.3"),
-        ("37.42.4b2", "v37.42.4"),
-        ("37.42.5rc3", "v37.42.5"),
-        ("37.42.6.post1", "v37.42.6"),
+        ("37.42.2.dev0+gad61a29.d20220919", "v37.42.2"),
+        ("37.42.3.dev73+gad61a29.d20220919", "v37.42.3"),
+        ("37.42.4a1", "v37.42.4"),
+        ("37.42.5b2", "v37.42.5"),
+        ("37.42.6rc3", "v37.42.6"),
+        ("37.42.7.post1", "v37.42.7"),
     ],
 )
 def test_new_app(
@@ -40,12 +41,13 @@ def test_new_app(
 ):
     """A new app can be created with the default template."""
     monkeypatch.setattr(briefcase, "__version__", briefcase_version)
-    app_context = {
-        "formal_name": "My Application",
-        "class_name": "MyApplication",
-        "app_name": "myapplication",
-    }
-    new_command.build_app_context = mock.MagicMock(return_value=app_context)
+    new_command.build_app_context = mock.MagicMock(
+        return_value={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+        }
+    )
     new_command.update_cookiecutter_cache = mock.MagicMock(
         return_value="~/.cookiecutters/briefcase-template"
     )
@@ -67,19 +69,29 @@ def test_new_app(
         no_input=True,
         output_dir=os.fsdecode(tmp_path),
         checkout=expected_branch,
-        extra_context=app_context,
+        extra_context={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+            # The expected app context
+            # should now also contain the
+            # default template and branch
+            "template": "https://github.com/beeware/briefcase-template",
+            "branch": expected_branch,
+        },
     )
 
 
 def test_new_app_missing_template(monkeypatch, new_command, tmp_path):
     """If a versioned branch doesn't exist, an error is raised."""
     monkeypatch.setattr(briefcase, "__version__", "37.42.7")
-    app_context = {
-        "formal_name": "My Application",
-        "class_name": "MyApplication",
-        "app_name": "myapplication",
-    }
-    new_command.build_app_context = mock.MagicMock(return_value=app_context)
+    new_command.build_app_context = mock.MagicMock(
+        return_value={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+        }
+    )
     new_command.update_cookiecutter_cache = mock.MagicMock(
         return_value="~/.cookiecutters/briefcase-template"
     )
@@ -109,20 +121,34 @@ def test_new_app_missing_template(monkeypatch, new_command, tmp_path):
         no_input=True,
         output_dir=os.fsdecode(tmp_path),
         checkout="v37.42.7",
-        extra_context=app_context,
+        extra_context={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+            # The expected app context
+            # should now also contain the
+            # default template and branch
+            "template": "https://github.com/beeware/briefcase-template",
+            "branch": "v37.42.7",
+        },
     )
 
 
-def test_new_app_dev(monkeypatch, new_command, tmp_path):
+@pytest.mark.parametrize(
+    "briefcase_version",
+    ("37.42.7.dev0+gad61a29.d20220919", "37.42.7.dev73+gad61a29.d20220919"),
+)
+def test_new_app_dev(monkeypatch, new_command, tmp_path, briefcase_version):
     """In a dev version, template will fall back to the 'main' branch if a
     versioned template doesn't exist."""
-    monkeypatch.setattr(briefcase, "__version__", "37.42.7.dev73+gad61a29.d20220919")
-    app_context = {
-        "formal_name": "My Application",
-        "class_name": "MyApplication",
-        "app_name": "myapplication",
-    }
-    new_command.build_app_context = mock.MagicMock(return_value=app_context)
+    monkeypatch.setattr(briefcase, "__version__", briefcase_version)
+    new_command.build_app_context = mock.MagicMock(
+        return_value={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+        }
+    )
     new_command.update_cookiecutter_cache = mock.MagicMock(
         return_value="~/.cookiecutters/briefcase-template"
     )
@@ -161,14 +187,32 @@ def test_new_app_dev(monkeypatch, new_command, tmp_path):
                 no_input=True,
                 output_dir=os.fsdecode(tmp_path),
                 checkout="v37.42.7",
-                extra_context=app_context,
+                extra_context={
+                    "formal_name": "My Application",
+                    "class_name": "MyApplication",
+                    "app_name": "myapplication",
+                    # The expected app context
+                    # should now also contain the
+                    # default template and branch
+                    "template": "https://github.com/beeware/briefcase-template",
+                    "branch": "v37.42.7",
+                },
             ),
             mock.call(
                 "~/.cookiecutters/briefcase-template",
                 no_input=True,
                 output_dir=os.fsdecode(tmp_path),
                 checkout="main",
-                extra_context=app_context,
+                extra_context={
+                    "formal_name": "My Application",
+                    "class_name": "MyApplication",
+                    "app_name": "myapplication",
+                    # The expected app context
+                    # should now also contain the
+                    # default template and branch
+                    "template": "https://github.com/beeware/briefcase-template",
+                    "branch": "v37.42.7",
+                },
             ),
         ]
     )
@@ -178,12 +222,13 @@ def test_new_app_with_template(monkeypatch, new_command, tmp_path):
     """A specific template can be requested."""
     monkeypatch.setattr(briefcase, "__version__", "37.42.7")
 
-    app_context = {
-        "formal_name": "My Application",
-        "class_name": "MyApplication",
-        "app_name": "myapplication",
-    }
-    new_command.build_app_context = mock.MagicMock(return_value=app_context)
+    new_command.build_app_context = mock.MagicMock(
+        return_value={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+        }
+    )
     new_command.update_cookiecutter_cache = mock.MagicMock(
         return_value="https://example.com/other.git"
     )
@@ -205,7 +250,16 @@ def test_new_app_with_template(monkeypatch, new_command, tmp_path):
         no_input=True,
         output_dir=os.fsdecode(tmp_path),
         checkout="v37.42.7",
-        extra_context=app_context,
+        extra_context={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+            # The expected app context
+            # should now also contain the
+            # template and branch
+            "template": "https://example.com/other.git",
+            "branch": "v37.42.7",
+        },
     )
 
 
@@ -213,12 +267,13 @@ def test_new_app_with_invalid_template(monkeypatch, new_command, tmp_path):
     """If the custom template is invalid, an error is raised."""
     monkeypatch.setattr(briefcase, "__version__", "37.42.7")
 
-    app_context = {
-        "formal_name": "My Application",
-        "class_name": "MyApplication",
-        "app_name": "myapplication",
-    }
-    new_command.build_app_context = mock.MagicMock(return_value=app_context)
+    new_command.build_app_context = mock.MagicMock(
+        return_value={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+        }
+    )
     new_command.update_cookiecutter_cache = mock.MagicMock(
         return_value="https://example.com/other.git"
     )
@@ -246,7 +301,16 @@ def test_new_app_with_invalid_template(monkeypatch, new_command, tmp_path):
         no_input=True,
         output_dir=os.fsdecode(tmp_path),
         checkout="v37.42.7",
-        extra_context=app_context,
+        extra_context={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+            # The expected app context
+            # should now also contain the
+            # template and branch
+            "template": "https://example.com/other.git",
+            "branch": "v37.42.7",
+        },
     )
 
 
@@ -255,12 +319,13 @@ def test_new_app_with_invalid_template_branch(monkeypatch, new_command, tmp_path
     is raised."""
     monkeypatch.setattr(briefcase, "__version__", "37.42.7")
 
-    app_context = {
-        "formal_name": "My Application",
-        "class_name": "MyApplication",
-        "app_name": "myapplication",
-    }
-    new_command.build_app_context = mock.MagicMock(return_value=app_context)
+    new_command.build_app_context = mock.MagicMock(
+        return_value={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+        }
+    )
     new_command.update_cookiecutter_cache = mock.MagicMock(
         return_value="https://example.com/other.git"
     )
@@ -290,7 +355,16 @@ def test_new_app_with_invalid_template_branch(monkeypatch, new_command, tmp_path
         no_input=True,
         output_dir=os.fsdecode(tmp_path),
         checkout="v37.42.7",
-        extra_context=app_context,
+        extra_context={
+            "formal_name": "My Application",
+            "class_name": "MyApplication",
+            "app_name": "myapplication",
+            # The expected app context
+            # should now also contain the
+            # template and branch
+            "template": "https://example.com/other.git",
+            "branch": "v37.42.7",
+        },
     )
 
 
