@@ -49,22 +49,31 @@ class DummyPublishCommand(PublishCommand):
         return "s3"
 
     def publish_app(self, app, channel, **kwargs):
-        self.actions.append(("publish", app.app_name, channel, kwargs))
+        self.actions.append(("publish", app.app_name, channel, kwargs.copy()))
         return full_options({"publish_state": app.app_name}, kwargs)
 
     # These commands override the default behavior, simply tracking that
     # they were invoked, rather than instantiating a Create/Update/Build command.
     # This is for testing purposes.
     def create_command(self, app, **kwargs):
-        self.actions.append(("create", app.app_name, kwargs))
+        self.actions.append(("create", app.app_name, kwargs.copy()))
+        # Remove arguments consumed by the underlying call to create_app()
+        kwargs.pop("test_mode", None)
         return full_options({"create_state": app.app_name}, kwargs)
 
     def update_command(self, app, **kwargs):
-        self.actions.append(("update", app.app_name, kwargs))
+        self.actions.append(("update", app.app_name, kwargs.copy()))
+        # Remove arguments consumed by the underlying call to update_app()
+        kwargs.pop("test_mode", None)
+        kwargs.pop("update_requirements", None)
+        kwargs.pop("update_resources", None)
         return full_options({"update_state": app.app_name}, kwargs)
 
     def build_command(self, app, **kwargs):
-        self.actions.append(("build", app.app_name, kwargs))
+        self.actions.append(("build", app.app_name, kwargs.copy()))
+        # Remove arguments consumed by the underlying call to build_app()
+        kwargs.pop("test_mode", None)
+        kwargs.pop("update", None)
         return full_options({"build_state": app.app_name}, kwargs)
 
 
