@@ -30,10 +30,10 @@ def test_update(update_command, first_app, second_app):
     assert update_command.actions == [
         ("verify",),
         # Update the first app
-        ("code", update_command.apps["first"]),
+        ("code", update_command.apps["first"], False),
         ("cleanup", update_command.apps["first"]),
         # Update the second app
-        ("code", update_command.apps["second"]),
+        ("code", update_command.apps["second"], False),
         ("cleanup", update_command.apps["second"]),
     ]
 
@@ -50,35 +50,14 @@ def test_update_single(update_command, first_app, second_app):
     assert update_command.actions == [
         ("verify",),
         # update the first app
-        ("code", update_command.apps["first"]),
+        ("code", update_command.apps["first"], False),
         ("cleanup", update_command.apps["first"]),
     ]
 
 
-def test_update_with_dependencies(update_command, first_app, second_app):
-    """The update command can be called, requesting a dependencies update."""
-    # Configure no command line options
-    options = update_command.parse_options(["-d"])
-
-    update_command(**options)
-
-    # The right sequence of things will be done
-    assert update_command.actions == [
-        ("verify",),
-        # Update the first app
-        ("dependencies", update_command.apps["first"]),
-        ("code", update_command.apps["first"]),
-        ("cleanup", update_command.apps["first"]),
-        # Update the second app
-        ("dependencies", update_command.apps["second"]),
-        ("code", update_command.apps["second"]),
-        ("cleanup", update_command.apps["second"]),
-    ]
-
-
-def test_update_with_resources(update_command, first_app, second_app):
-    """The update command can be called, requesting a resources update."""
-    # Configure no command line options
+def test_update_with_requirements(update_command, first_app, second_app):
+    """The update command can be called, requesting a requirements update."""
+    # Configure a requirements update
     options = update_command.parse_options(["-r"])
 
     update_command(**options)
@@ -87,11 +66,32 @@ def test_update_with_resources(update_command, first_app, second_app):
     assert update_command.actions == [
         ("verify",),
         # Update the first app
-        ("code", update_command.apps["first"]),
+        ("code", update_command.apps["first"], False),
+        ("requirements", update_command.apps["first"], False),
+        ("cleanup", update_command.apps["first"]),
+        # Update the second app
+        ("code", update_command.apps["second"], False),
+        ("requirements", update_command.apps["second"], False),
+        ("cleanup", update_command.apps["second"]),
+    ]
+
+
+def test_update_with_resources(update_command, first_app, second_app):
+    """The update command can be called, requesting a resources update."""
+    # Configure no command line options
+    options = update_command.parse_options(["--update-resources"])
+
+    update_command(**options)
+
+    # The right sequence of things will be done
+    assert update_command.actions == [
+        ("verify",),
+        # Update the first app
+        ("code", update_command.apps["first"], False),
         ("resources", update_command.apps["first"]),
         ("cleanup", update_command.apps["first"]),
         # Update the second app
-        ("code", update_command.apps["second"]),
+        ("code", update_command.apps["second"], False),
         ("resources", update_command.apps["second"]),
         ("cleanup", update_command.apps["second"]),
     ]
