@@ -8,12 +8,12 @@ from briefcase.console import Console
 @pytest.fixture
 def console():
     console = Console()
-    console._input = mock.MagicMock()
+    console.input = mock.MagicMock()
     return console
 
 
 @pytest.fixture
 def disabled_console():
     console = Console(enabled=False)
-    console._input = mock.MagicMock()
+    console.input = mock.MagicMock()
     return console
