@@ -99,45 +99,6 @@ def test_succeeds_immediately_in_happy_path(mock_tools, tmp_path):
     assert sdk.root_path == android_sdk_root_path
 
 
-def test_succeeds_immediately_in_happy_path_with_debug(mock_tools, tmp_path):
-    """If debug is enabled, a verify call will display the installed
-    packages."""
-    # Increase the log level.
-    mock_tools.logger.verbosity = 2
-
-    # If `sdkmanager` exists and has the right permissions, and
-    # `android-sdk-license` exists, verify() should
-    # succeed, create no subprocesses, make no requests, and return a
-    # SDK wrapper.
-
-    # On Windows, this requires `sdkmanager.bat`; on non-Windows, it requires
-    # `sdkmanager`.
-
-    # Create `sdkmanager` and the license file.
-    android_sdk_root_path = tmp_path / "tools" / "android_sdk"
-    tools_bin = android_sdk_root_path / "cmdline-tools" / "latest" / "bin"
-    tools_bin.mkdir(parents=True, mode=0o755)
-    if platform.system() == "Windows":
-        sdk_manager = tools_bin / "sdkmanager.bat"
-        sdk_manager.touch()
-    else:
-        sdk_manager = tools_bin / "sdkmanager"
-        sdk_manager.touch(mode=0o755)
-
-    # Pre-accept the license
-    accept_license(android_sdk_root_path)()
-
-    # Expect verify() to succeed
-    sdk = AndroidSDK.verify(mock_tools)
-
-    # No calls to download or unpack anything.
-    mock_tools.download.file.assert_not_called()
-    mock_tools.shutil.unpack_archive.assert_not_called()
-
-    # The returned SDK has the expected root path.
-    assert sdk.root_path == android_sdk_root_path
-
-
 def test_user_provided_sdk(mock_tools, tmp_path):
     """If the user specifies a valid ANDROID_SDK_ROOT, it is used."""
     # Increase the log level.
@@ -173,40 +134,6 @@ def test_user_provided_sdk(mock_tools, tmp_path):
     assert sdk.root_path == existing_android_sdk_root_path
 
 
-def test_user_provided_sdk_with_debug(mock_tools, tmp_path):
-    """If the has debug with a user-specified ANDROID_SDK_ROOT, the packages
-    are listed."""
-    # Create `sdkmanager` and the license file.
-    existing_android_sdk_root_path = tmp_path / "other_sdk"
-    tools_bin = existing_android_sdk_root_path / "cmdline-tools" / "latest" / "bin"
-    tools_bin.mkdir(parents=True, mode=0o755)
-    if platform.system() == "Windows":
-        sdk_manager = tools_bin / "sdkmanager.bat"
-        sdk_manager.touch()
-    else:
-        sdk_manager = tools_bin / "sdkmanager"
-        sdk_manager.touch(mode=0o755)
-
-    # Pre-accept the license
-    accept_license(existing_android_sdk_root_path)()
-
-    # Set the environment to specify ANDROID_SDK_ROOT
-    mock_tools.os.environ = {
-        "ANDROID_SDK_ROOT": os.fsdecode(existing_android_sdk_root_path)
-    }
-
-    # Expect verify() to succeed
-    sdk = AndroidSDK.verify(mock_tools)
-
-    # No calls to download, run or unpack anything.
-    mock_tools.download.file.assert_not_called()
-    mock_tools.subprocess.run.assert_not_called()
-    mock_tools.shutil.unpack_archive.assert_not_called()
-
-    # The returned SDK has the expected root path.
-    assert sdk.root_path == existing_android_sdk_root_path
-
-
 def test_invalid_user_provided_sdk(mock_tools, tmp_path):
     """If the user specifies an invalid ANDROID_SDK_ROOT, it is ignored."""
 
