@@ -1,6 +1,6 @@
 import pytest
 
-from ....utils import create_file
+from ....utils import create_file, create_plist_file
 
 
 @pytest.fixture
@@ -12,6 +12,14 @@ def first_app_generated(first_app_config, tmp_path):
 [paths]
 app_packages_path="app_packages"
 support_path="support"
+info_plist_path="Info.plist"
 """,
     )
+
+    create_plist_file(
+        tmp_path / "base_path" / "iOS" / "Xcode" / "First App" / "Info.plist",
+        {
+            "MainModule": "first_app",
+        },
+    )
     return first_app_config
