@@ -18,7 +18,7 @@ def test_extra_pip_args(first_app_generated, tmp_path):
 
     command.tools[first_app_generated].app_context = MagicMock(spec_set=Subprocess)
 
-    command.install_app_dependencies(first_app_generated)
+    command.install_app_requirements(first_app_generated, test_mode=False)
 
     command.tools[first_app_generated].app_context.run.assert_called_once_with(
         [
