@@ -1,11 +1,17 @@
 import pytest
 
+from briefcase.console import Console, Log
 from briefcase.platforms.iOS.xcode import iOSXcodePackageCommand
 
 
 @pytest.fixture
 def package_command(tmp_path, first_app_config):
-    command = iOSXcodePackageCommand(base_path=tmp_path / "base_path")
+    command = iOSXcodePackageCommand(
+        logger=Log(),
+        console=Console(),
+        base_path=tmp_path / "base_path",
+        data_path=tmp_path / "briefcase",
+    )
     command.data_path = tmp_path / "briefcase"
     return command
 
