@@ -9,7 +9,6 @@ from briefcase.console import Console, Log
 from briefcase.exceptions import (
     InvalidFormatError,
     NoCommandError,
-    ShowOutputFormats,
     UnsupportedCommandError,
 )
 from briefcase.platforms.linux.appimage import LinuxAppImageCreateCommand
@@ -43,9 +42,10 @@ def test_empty():
     assert excinfo.value.msg.startswith(
         "usage: briefcase [-h] <command> [<platform>] [<format>] ...\n"
         "\n"
-        "Package Python code for distribution.\n"
+        "Briefcase is a tool for converting a Python project into a standalone native\n"
+        "application for distribution.\n"
         "\n"
-        "positional arguments:\n"
+        "Commands:\n"
     )
 
 
@@ -57,9 +57,10 @@ def test_help_only():
     assert excinfo.value.msg.startswith(
         "usage: briefcase [-h] <command> [<platform>] [<format>] ...\n"
         "\n"
-        "Package Python code for distribution.\n"
+        "Briefcase is a tool for converting a Python project into a standalone native\n"
+        "application for distribution.\n"
         "\n"
-        "positional arguments:\n"
+        "Commands:\n"
     )
 
 
@@ -75,20 +76,6 @@ def test_version_only(capsys):
     assert output == f"{__version__}\n"
 
 
-def test_show_output_formats_only():
-    """``briefcase -f`` returns basic usage as a command is needed."""
-    with pytest.raises(NoCommandError, match=r"usage: briefcase") as excinfo:
-        cmdline.parse_cmdline("-f".split())
-
-    assert excinfo.value.msg.startswith(
-        "usage: briefcase [-h] <command> [<platform>] [<format>] ...\n"
-        "\n"
-        "Package Python code for distribution.\n"
-        "\n"
-        "positional arguments:\n"
-    )
-
-
 def test_unknown_command():
     """``briefcase foobar`` fails as an invalid command."""
     with pytest.raises(SystemExit) as excinfo:
@@ -129,7 +116,12 @@ def test_dev_command(monkeypatch, logger, console):
     assert cmd.logger.verbosity == 1
     assert cmd.logger is logger
     assert cmd.input is console
-    assert options == {"appname": None, "update_dependencies": False, "run_app": True}
+    assert options == {
+        "appname": None,
+        "update_requirements": False,
+        "run_app": True,
+        "test_mode": False,
+    }
 
 
 def test_upgrade_command(monkeypatch, logger, console):
@@ -251,20 +243,6 @@ def test_bare_command_version(capsys, logger, console):
     assert output == f"{__version__}\n"
 
 
-def test_bare_command_show_formats(monkeypatch, logger, console):
-    """``briefcase create -f`` returns an error indicating a platform is
-    needed."""
-    # Pretend we're on macOS, regardless of where the tests run.
-    monkeypatch.setattr(sys, "platform", "darwin")
-
-    with pytest.raises(ShowOutputFormats) as excinfo:
-        do_cmdline_parse("create -f".split(), logger, console)
-
-    assert excinfo.value.platform == "macOS"
-    assert excinfo.value.default == "app"
-    assert set(excinfo.value.choices) == {"xcode", "app"}
-
-
 def test_command_unknown_platform(monkeypatch, logger, console):
     """``briefcase create foobar`` raises an unknown platform error."""
     # Pretend we're on macOS, regardless of where the tests run.
@@ -335,19 +313,6 @@ def test_command_explicit_platform_help(monkeypatch, capsys, logger, console):
     )
 
 
-def test_command_explicit_platform_show_formats(monkeypatch, logger, console):
-    """``briefcase create macOS -f`` shows formats for the platform."""
-    # Pretend we're on macOS, regardless of where the tests run.
-    monkeypatch.setattr(sys, "platform", "darwin")
-
-    with pytest.raises(ShowOutputFormats) as excinfo:
-        do_cmdline_parse("create macOS -f".split(), logger, console)
-
-    assert excinfo.value.platform == "macOS"
-    assert excinfo.value.default == "app"
-    assert set(excinfo.value.choices) == {"xcode", "app"}
-
-
 def test_command_explicit_format(monkeypatch, logger, console):
     """``briefcase create macOS app`` returns the macOS create app command."""
     # Pretend we're on macOS, regardless of where the tests run.
@@ -370,7 +335,7 @@ def test_command_unknown_format(monkeypatch, logger, console):
     # Pretend we're on macOS, regardless of where the tests run.
     monkeypatch.setattr(sys, "platform", "darwin")
 
-    expected_exc_regex = r"Invalid format 'foobar'; \(choose from: app, xcode\)"
+    expected_exc_regex = r"Invalid format 'foobar'; \(choose from: app, Xcode\)"
     with pytest.raises(InvalidFormatError, match=expected_exc_regex):
         do_cmdline_parse("create macOS foobar".split(), logger, console)
 
@@ -414,19 +379,6 @@ def test_command_explicit_format_help(monkeypatch, capsys, logger, console):
     )
 
 
-def test_command_explicit_format_show_formats(monkeypatch, logger, console):
-    """``briefcase create macOS app -f`` shows formats for the platform."""
-    # Pretend we're on macOS, regardless of where the tests run.
-    monkeypatch.setattr(sys, "platform", "darwin")
-
-    with pytest.raises(ShowOutputFormats) as excinfo:
-        do_cmdline_parse("create macOS app -f".split(), logger, console)
-
-    assert excinfo.value.platform == "macOS"
-    assert excinfo.value.default == "app"
-    assert set(excinfo.value.choices) == {"xcode", "app"}
-
-
 def test_command_disable_input(monkeypatch, logger, console):
     """``briefcase create --no-input`` disables console input."""
     # Pretend we're on macOS, regardless of where the tests run.
